import { Component, EventEmitter, Output, Input } from '@angular/core';
import { HorizontalAlignment_$type } from "igniteui-angular-core";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { TrendLineType_$type } from "igniteui-angular-core";
import { IgxChartSeriesEventArgs } from './igx-chart-series-event-args';
import { arrayFindByName, brushToString, stringToBrush, toBrushCollection, fromBrushCollection, fromRect, toRect, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss, NamePatcher } from "igniteui-angular-core";
import { MarkerType_$type } from "./MarkerType";
import { delegateCombine } from "igniteui-angular-core";
import { IgxDomainChartSeriesPointerEventArgs } from './igx-domain-chart-series-pointer-event-args';
import { MarkerTypeCollection as MarkerTypeCollection_internal } from './MarkerTypeCollection';
import { IgxMarkerTypeCollection } from './igx-marker-type-collection';
import { SyncableObservableCollection$1 } from "igniteui-angular-core";
import { ToolTipType_$type } from "./ToolTipType";
import { CrosshairsDisplayMode_$type } from "./CrosshairsDisplayMode";
import { IgxCalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { ComputedPlotAreaMarginMode_$type } from './ComputedPlotAreaMarginMode';
import { SeriesHighlightingMode_$type } from './SeriesHighlightingMode';
import { SeriesHighlightingBehavior_$type } from './SeriesHighlightingBehavior';
import { LegendHighlightingMode_$type } from './LegendHighlightingMode';
import { SeriesOutlineMode_$type } from './SeriesOutlineMode';
import { MarkerOutlineMode_$type } from './MarkerOutlineMode';
import { MarkerFillMode_$type } from './MarkerFillMode';
import { MarkerAutomaticBehavior_$type } from './MarkerAutomaticBehavior';
import { LegendItemBadgeMode_$type } from "igniteui-angular-core";
import { LegendItemBadgeShape_$type } from "igniteui-angular-core";
import { DataAbbreviationMode_$type } from "igniteui-angular-core";
import { DataLegendValueMode_$type } from "igniteui-angular-core";
import { DataLegendHeaderDateMode_$type } from "igniteui-angular-core";
import { DataLegendHeaderTimeMode_$type } from "igniteui-angular-core";
import { DataLegendUnitsMode_$type } from "igniteui-angular-core";
import { DataLegendLabelMode_$type } from "igniteui-angular-core";
import { DataLegendSummaryType_$type } from "igniteui-angular-core";
import { Thickness } from "igniteui-angular-core";
import { FontInfo } from "igniteui-angular-core";
import { SeriesPlotAreaMarginHorizontalMode_$type } from './SeriesPlotAreaMarginHorizontalMode';
import { SeriesPlotAreaMarginVerticalMode_$type } from './SeriesPlotAreaMarginVerticalMode';
import { IgxCalloutPlacementPositionsCollection } from './igx-callout-placement-positions-collection';
import { CalloutPlacementPositions_$type } from './CalloutPlacementPositions';
import { SeriesViewerScrollbarMode_$type } from './SeriesViewerScrollbarMode';
import { SeriesViewerHorizontalScrollbarPosition_$type } from './SeriesViewerHorizontalScrollbarPosition';
import { SeriesViewerVerticalScrollbarPosition_$type } from './SeriesViewerVerticalScrollbarPosition';
import { IgxCalloutRenderStyleUpdatingEventArgs } from './igx-callout-render-style-updating-event-args';
import { CalloutPlacementPositionsCollection as CalloutPlacementPositionsCollection_internal } from './CalloutPlacementPositionsCollection';
import { DataToolTipLayerGroupingMode_$type } from "igniteui-angular-core";
import { DataTooltipGroupedPositionX_$type } from "igniteui-angular-core";
import { DataTooltipGroupedPositionY_$type } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents a base class for all domain charts that can plot scatter data and shapefiles
*
* ```html
* <igx-category-chart
*       yAxisMinimumValue="0"
*       [dataSource]="data"
*       bottomMargin= 20>
*     </igx-category-chart>
* ```
*/
var IgxDomainChartComponent = /** @class */ /*@__PURE__*/ (function () {
    function IgxDomainChartComponent() {
        this._calloutsDataSource = null;
        this._markerTypes = null;
        this._calloutsAllowedPositions = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._seriesAdded = null;
        this._seriesRemoved = null;
        this._seriesPointerEnter = null;
        this._seriesPointerLeave = null;
        this._seriesPointerMove = null;
        this._seriesPointerDown = null;
        this._seriesPointerUp = null;
        this._calloutStyleUpdating = null;
        this._calloutRenderStyleUpdating = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxDomainChartComponent.prototype.createImplementation = function () {
        return null;
    };
    IgxDomainChartComponent.prototype.ngOnInit = function () {
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.onImplementationCreated = function () {
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "tooltipTemplate", {
        /**
        * Sets or gets the template reference to use for tooltips for all the series.
        *
        *
        */
        get: function () {
            return this.i.tooltipTemplate;
        },
        set: function (v) {
            this.i.tooltipTemplate = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "tooltipTemplates", {
        /**
        * Sets or gets the template references to use for tooltips for all the series, in order.
        *
        *
        */
        get: function () {
            var ret = [];
            if (this.i.tooltipTemplates) {
                for (var ii = 0; ii < this.i.tooltipTemplates.count; ii++) {
                    ret.push(this.i.tooltipTemplates.item(ii));
                }
            }
            return ret;
        },
        set: function (v) {
            this.i.tooltipTemplates.clear();
            if (v) {
                for (var ii = 0; ii < v.length; ii++) {
                    this.i.tooltipTemplates.add(v[ii]);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "legend", {
        get: function () {
            if (this.i.legend != null)
                return this.i.legend.externalObject;
        },
        set: function (v) {
            if (v != undefined && v != null)
                this.i.legend = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsDataSource", {
        get: function () {
            return this._calloutsDataSource;
        },
        set: function (value) {
            this._calloutsDataSource = value;
            this.bindCalloutsData();
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.bindCalloutsData = function () {
        if (this.i != null && this.i !== undefined) {
            this.i.calloutsItemsSource = this._calloutsDataSource;
        }
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "pixelScalingRatio", {
        /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
        get: function () {
            return this.i.hi;
        },
        set: function (v) {
            this.i.hi = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleLeftMargin", {
        /**
         * Gets or sets the left margin of chart title
        *
        *  Use `titleLeftMargin` property for the left margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        * 	titleLeftMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleLeftMargin = 10;
        * ```
        */
        get: function () {
            return this.i.hv;
        },
        set: function (v) {
            this.i.hv = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleRightMargin", {
        /**
         * Gets or sets the right margin of chart title
        *
        *  Use `titleLeftMargin` property for the right margin of chart title.
        *
        * ```html
        * <igx-category-chart
        * 		yAxisMinimumValue="0"
        * 		[dataSource]="data"
        * 		titleRightMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleRightMargin = 10;
        * ```
        */
        get: function () {
            return this.i.hw;
        },
        set: function (v) {
            this.i.hw = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleTopMargin", {
        /**
         * Gets or sets the top margin of chart title
        *
        *  Use `titleTopMargin` property for the top margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *      yAxisMinimumValue="0"
        *      [dataSource]="data"
        *      title="Countries"
        *      titleTopMargin=10 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleTopMargin = 10;
        * ```
        */
        get: function () {
            return this.i.hx;
        },
        set: function (v) {
            this.i.hx = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleBottomMargin", {
        /**
         * Gets or sets the bottom margin of chart title
        *
        *  Use `titleBottomMargin` property for the bottom margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *    yAxisMinimumValue="0"
        *    [dataSource]="data"
        *    titleBottomMargin= 10 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.titleBottomMargin = 5;
        * ```
        */
        get: function () {
            return this.i.hu;
        },
        set: function (v) {
            this.i.hu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleLeftMargin", {
        /**
         * Gets or sets the left margin of chart subtitle
        *
        * Use `subtitleLeftMargin` property for the left margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleLeftMargin= 20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleLeftMargin = 20 ;
        * ```
        */
        get: function () {
            return this.i.hq;
        },
        set: function (v) {
            this.i.hq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleTopMargin", {
        /**
         * Gets or sets the top margin of chart subtitle
        *
        * Use `subtitleTopMargin` property for the top margin of chart subtitle.
        *
        * ```html
        *    <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTopMargin=10>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTopMargin = 10;
        * ```
        */
        get: function () {
            return this.i.hs;
        },
        set: function (v) {
            this.i.hs = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleRightMargin", {
        /**
         * Gets or sets the right margin of chart subtitle
        *
        * Use `subtitleRightMargin` property for the right margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleRightMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.subtitleRightMargin = 20 ;
        * ```
        */
        get: function () {
            return this.i.hr;
        },
        set: function (v) {
            this.i.hr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of chart subtitle
        *
        * Use `subtitleBottomMargin` property for the bottom margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        * 	subtitleBottomMargin=10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleBottomMargin = 10 ;
        * ```
        */
        get: function () {
            return this.i.hp;
        },
        set: function (v) {
            this.i.hp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleTextColor", {
        /**
         * Gets or sets color of chart subtitle
        *
        * Use `subtitleTextColor` property to color the subtitle.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTextColor= 'blue'>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTextColor = "#ff0000" ;
        * ```
        */
        get: function () {
            return brushToString(this.i.s0);
        },
        set: function (v) {
            this.i.s0 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleTextColor", {
        /**
         * Gets or sets color of chart title
        *
        *  Use `titleTextColor` property to color the chart title
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       titleTextColor= "red">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.titleTextColor="red" ;
        * ```
        */
        get: function () {
            return brushToString(this.i.s1);
        },
        set: function (v) {
            this.i.s1 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "leftMargin", {
        /**
         * Gets or sets the left margin of the chart content.
        *
        * Use the 'leftMargin' property for the left margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       leftMargin=20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.leftMargin = 20;
        * ```
        */
        get: function () {
            return this.i.hf;
        },
        set: function (v) {
            this.i.hf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "topMargin", {
        /**
         * Gets or sets the top margin of the chart content.
        *
        * Use `topMargin` property for the margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     topMargin= 20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.topMargin=20;
        * ```
        */
        get: function () {
            return this.i.hy;
        },
        set: function (v) {
            this.i.hy = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "rightMargin", {
        /**
         * Gets or sets the right margin of the chart content.
        *
        * Use `rightMargin` property for the right margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     rightMargin=20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *   this.chart.rightMargin = 20 ;
        * ```
        */
        get: function () {
            return this.i.ho;
        },
        set: function (v) {
            this.i.ho = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "bottomMargin", {
        /**
         * Gets or sets the bottom margin around the chart content.
        *
        * Use the `bottomMargin` property for the bottom margin around the chart content.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       bottomMargin= 20>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.bottomMargin=20;
        * ```
        */
        get: function () {
            return this.i.g2;
        },
        set: function (v) {
            this.i.g2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "transitionDuration", {
        /**
         * Gets or sets the duration used for animating series plots when the data is changing
        *
        * Use the `transitionDuration` property to animating between data values.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     transitionDuration="500">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.transitionDuratio= 500;
        * ```
        */
        get: function () {
            return this.i.iq;
        },
        set: function (v) {
            this.i.iq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "transitionEasingFunction", {
        /**
         * Gets or sets the easing function used for animating series plots when the data is changing.
         * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
        *
        * The 'transitionInEasingFunction' property used for easing function for animating series plots when the chart is loading into view.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     transitionInEasingFunction= "cubic">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.transitionInEasingFunction=  this.cubicFunc;
        *
        * cubicFunc(time: number) : number
        *   {
        *     return time;
        *   }
        * ```
        */
        get: function () {
            return this.i.c8;
        },
        set: function (v) {
            this.i.c8 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleTextStyle", {
        /**
         * Gets or sets CSS font property for the chart subtitle
        *
        * Use `subtitleTextStyle` property for the CSS font of the chart subtitle.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTextStyle ="16pt Verdona">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTextStyle= "16pt Verdona";
        * ```
        */
        get: function () {
            return this.i.od;
        },
        set: function (v) {
            this.i.od = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleTextStyle", {
        /**
         * Gets or sets CSS font property for the chart title
        *
        * Use `titleTextStyle` property for the CSS font property of the chart title
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       titleTextStyle= "24pt Verdona">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.xAxisTitleTextStyle = "24pt Verdona";
        * ```
        */
        get: function () {
            return this.i.oo;
        },
        set: function (v) {
            this.i.oo = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipGroupingMode", {
        get: function () {
            return this.i.bc;
        },
        set: function (v) {
            this.i.bc = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipPositionOffsetX", {
        /**
         * Gets or sets the offset of the tooltip layer on the X axis.
        */
        get: function () {
            return this.i.g6;
        },
        set: function (v) {
            this.i.g6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipPositionOffsetY", {
        /**
         * Gets or sets the offset of the tooltip layer on the Y axis.
        */
        get: function () {
            return this.i.g7;
        },
        set: function (v) {
            this.i.g7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipDefaultPositionOffsetX", {
        /**
         * Gets or sets the offset of the tooltip layer on the X axis.
        */
        get: function () {
            return this.i.g4;
        },
        set: function (v) {
            this.i.g4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipDefaultPositionOffsetY", {
        /**
         * Gets or sets the offset of the tooltip layer on the Y axis.
        */
        get: function () {
            return this.i.g5;
        },
        set: function (v) {
            this.i.g5 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipGroupedPositionModeX", {
        /**
         * Gets or sets the tooltip position mode on the X axis for grouped series.
        */
        get: function () {
            return this.i.a8;
        },
        set: function (v) {
            this.i.a8 = ensureEnum(DataTooltipGroupedPositionX_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipGroupedPositionModeY", {
        /**
         * Gets or sets the tooltip position mode on the Y axis for grouped series.
        */
        get: function () {
            return this.i.ba;
        },
        set: function (v) {
            this.i.ba = ensureEnum(DataTooltipGroupedPositionY_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipShouldUpdateWhenSeriesDataChanges", {
        /**
         * Gets or sets whether the data legend should update when the series data is mutated.
        */
        get: function () {
            return this.i.eo;
        },
        set: function (v) {
            this.i.eo = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipIncludedSeries", {
        /**
         * Gets or sets indexes or names of series to include in displaying in the data legend, e.g. "0, 1"
        */
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.m = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipExcludedSeries", {
        /**
         * Gets or sets indexes or names of series to exclude from displaying in the data legend, e.g. "0, 1"
         * The ExcludedSeries property takes precedences over values of IncludedSeries property
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.j = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipIncludedColumns", {
        /**
         * Gets or sets names of data columns or their labels to include in displaying in the data legend, e.g. "High, Low" or "H, L"
         * The ExcludedColumns property takes precedences over values of IncludedColumns property
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.l = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipExcludedColumns", {
        /**
         * Gets or sets names of data columns or their labels to exclude from displaying in the data legend, e.g. "High, Low" or "H, L"
         * The ExcludedColumns property takes precedences over values of IncludedColumns property
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.i = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatAbbreviation", {
        /**
         * Gets or sets mode for abbreviating large numbers displayed in the legend
         * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
        */
        get: function () {
            return this.i.as;
        },
        set: function (v) {
            this.i.as = ensureEnum(DataAbbreviationMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatMaxFractions", {
        /**
         * Gets or sets maximum digits for formating numbers displayed in the legend
         * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
        */
        get: function () {
            return this.i.il;
        },
        set: function (v) {
            this.i.il = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatMinFractions", {
        /**
         * Gets or sets minimum digits for formating numbers displayed in the legend
         * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
        */
        get: function () {
            return this.i.im;
        },
        set: function (v) {
            this.i.im = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatMode", {
        /**
         * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
        */
        get: function () {
            return this.i.a6;
        },
        set: function (v) {
            this.i.a6 = ensureEnum(DataLegendValueMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatCulture", {
        /**
         * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
         * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
        */
        get: function () {
            return this.i.l6;
        },
        set: function (v) {
            this.i.l6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatUseGrouping", {
        /**
         * Gets or sets whether or not use groupping sperator, e.g, 15,000 for 15000
         * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
        */
        get: function () {
            return this.i.ep;
        },
        set: function (v) {
            this.i.ep = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatString", {
        /**
         * Gets or sets the format string for values displayed in the data legend.
        */
        get: function () {
            return this.i.mc;
        },
        set: function (v) {
            this.i.mc = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the ValueFormatString string.
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.n = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueRowMarginBottom", {
        get: function () {
            return this.i.tq ? this.i.tq.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueRowMargin();
            this.i.tq.bottom = +v;
            this.i.tq = this.i.tq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueRowMarginLeft", {
        get: function () {
            return this.i.tq ? this.i.tq.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueRowMargin();
            this.i.tq.left = +v;
            this.i.tq = this.i.tq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueRowMarginRight", {
        get: function () {
            return this.i.tq ? this.i.tq.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueRowMargin();
            this.i.tq.right = +v;
            this.i.tq = this.i.tq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueRowMarginTop", {
        get: function () {
            return this.i.tq ? this.i.tq.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueRowMargin();
            this.i.tq.top = +v;
            this.i.tq = this.i.tq;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipValueRowMargin = function () {
        if (this.i.tq) {
            return;
        }
        this.i.tq = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueRowVisible", {
        /**
         * Gets or sets whether to show series rows.
        */
        get: function () {
            return this.i.eq;
        },
        set: function (v) {
            this.i.eq = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextWhenMissingData", {
        /**
         * Gets or sets text displayed when data column is missing a value, e.g. "no data"
        */
        get: function () {
            return this.i.ml;
        },
        set: function (v) {
            this.i.ml = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextUseSeriesColors", {
        /**
         * Gets or sets whether to use series colors when displaying values in the legend
        */
        get: function () {
            return this.i.er;
        },
        set: function (v) {
            this.i.er = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextMarginBottom", {
        get: function () {
            return this.i.tr ? this.i.tr.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueTextMargin();
            this.i.tr.bottom = +v;
            this.i.tr = this.i.tr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextMarginLeft", {
        get: function () {
            return this.i.tr ? this.i.tr.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueTextMargin();
            this.i.tr.left = +v;
            this.i.tr = this.i.tr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextMarginRight", {
        get: function () {
            return this.i.tr ? this.i.tr.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueTextMargin();
            this.i.tr.right = +v;
            this.i.tr = this.i.tr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextMarginTop", {
        get: function () {
            return this.i.tr ? this.i.tr.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipValueTextMargin();
            this.i.tr.top = +v;
            this.i.tr = this.i.tr;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipValueTextMargin = function () {
        if (this.i.tr) {
            return;
        }
        this.i.tr = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sq);
        },
        set: function (v) {
            this.i.sq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipValueTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dr == null) {
                return null;
            }
            return this.i.dr.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dr = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderFormatString", {
        /**
         * Gets or sets the format string for header text displayed in the data legend.
        */
        get: function () {
            return this.i.kw;
        },
        set: function (v) {
            this.i.kw = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the HeaderFormatString string.
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.k = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderFormatCulture", {
        /**
         * Gets or sets globalization culture when displaying header as date time
         * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
        */
        get: function () {
            return this.i.ks;
        },
        set: function (v) {
            this.i.ks = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderFormatDate", {
        /**
         * Gets or sets date format for the header
         * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
        */
        get: function () {
            return this.i.aw;
        },
        set: function (v) {
            this.i.aw = ensureEnum(DataLegendHeaderDateMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderFormatTime", {
        /**
         * Gets or sets time format for the header
         * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
        */
        get: function () {
            return this.i.ay;
        },
        set: function (v) {
            this.i.ay = ensureEnum(DataLegendHeaderTimeMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderText", {
        /**
         * Gets or sets the HeaderText for the data legend.
        */
        get: function () {
            return this.i.k1;
        },
        set: function (v) {
            this.i.k1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextColor", {
        /**
         * Gets or sets the header text color.
        */
        get: function () {
            return brushToString(this.i.si);
        },
        set: function (v) {
            this.i.si = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextMarginBottom", {
        get: function () {
            return this.i.tk ? this.i.tk.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderTextMargin();
            this.i.tk.bottom = +v;
            this.i.tk = this.i.tk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextMarginLeft", {
        get: function () {
            return this.i.tk ? this.i.tk.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderTextMargin();
            this.i.tk.left = +v;
            this.i.tk = this.i.tk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextMarginRight", {
        get: function () {
            return this.i.tk ? this.i.tk.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderTextMargin();
            this.i.tk.right = +v;
            this.i.tk = this.i.tk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextMarginTop", {
        get: function () {
            return this.i.tk ? this.i.tk.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderTextMargin();
            this.i.tk.top = +v;
            this.i.tk = this.i.tk;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipHeaderTextMargin = function () {
        if (this.i.tk) {
            return;
        }
        this.i.tk = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderRowMarginBottom", {
        get: function () {
            return this.i.tj ? this.i.tj.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderRowMargin();
            this.i.tj.bottom = +v;
            this.i.tj = this.i.tj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderRowMarginLeft", {
        get: function () {
            return this.i.tj ? this.i.tj.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderRowMargin();
            this.i.tj.left = +v;
            this.i.tj = this.i.tj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderRowMarginRight", {
        get: function () {
            return this.i.tj ? this.i.tj.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderRowMargin();
            this.i.tj.right = +v;
            this.i.tj = this.i.tj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderRowMarginTop", {
        get: function () {
            return this.i.tj ? this.i.tj.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipHeaderRowMargin();
            this.i.tj.top = +v;
            this.i.tj = this.i.tj;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipHeaderRowMargin = function () {
        if (this.i.tj) {
            return;
        }
        this.i.tj = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderRowVisible", {
        /**
         * Gets or sets whether to show Header row.
        */
        get: function () {
            return this.i.en;
        },
        set: function (v) {
            this.i.en = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipHeaderTextStyle", {
        /**
         * Gets or Sets the style to use for the header text.
        */
        get: function () {
            if (this.i.di == null) {
                return null;
            }
            return this.i.di.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.di = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextColor", {
        /**
         * Gets or sets the summary text color.
        */
        get: function () {
            return brushToString(this.i.sl);
        },
        set: function (v) {
            this.i.sl = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextStyle", {
        /**
         * Gets or Sets the style to use for the summary text.
        */
        get: function () {
            if (this.i.dl == null) {
                return null;
            }
            return this.i.dl.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dl = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryType", {
        /**
         * Gets or sets the SummaryType for the data legend.
        */
        get: function () {
            return this.i.a2;
        },
        set: function (v) {
            this.i.a2 = ensureEnum(DataLegendSummaryType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleText", {
        /**
         * Gets or sets the SummaryTitleText for the data legend.
        */
        get: function () {
            return this.i.lk;
        },
        set: function (v) {
            this.i.lk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextMarginBottom", {
        get: function () {
            return this.i.tn ? this.i.tn.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryTitleTextMargin();
            this.i.tn.bottom = +v;
            this.i.tn = this.i.tn;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextMarginLeft", {
        get: function () {
            return this.i.tn ? this.i.tn.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryTitleTextMargin();
            this.i.tn.left = +v;
            this.i.tn = this.i.tn;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextMarginRight", {
        get: function () {
            return this.i.tn ? this.i.tn.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryTitleTextMargin();
            this.i.tn.right = +v;
            this.i.tn = this.i.tn;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryTitleTextMarginTop", {
        get: function () {
            return this.i.tn ? this.i.tn.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryTitleTextMargin();
            this.i.tn.top = +v;
            this.i.tn = this.i.tn;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipSummaryTitleTextMargin = function () {
        if (this.i.tn) {
            return;
        }
        this.i.tn = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryRowMarginBottom", {
        get: function () {
            return this.i.tm ? this.i.tm.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryRowMargin();
            this.i.tm.bottom = +v;
            this.i.tm = this.i.tm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryRowMarginLeft", {
        get: function () {
            return this.i.tm ? this.i.tm.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryRowMargin();
            this.i.tm.left = +v;
            this.i.tm = this.i.tm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryRowMarginRight", {
        get: function () {
            return this.i.tm ? this.i.tm.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryRowMargin();
            this.i.tm.right = +v;
            this.i.tm = this.i.tm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryRowMarginTop", {
        get: function () {
            return this.i.tm ? this.i.tm.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipSummaryRowMargin();
            this.i.tm.top = +v;
            this.i.tm = this.i.tm;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipSummaryRowMargin = function () {
        if (this.i.tm) {
            return;
        }
        this.i.tm = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryValueTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sn);
        },
        set: function (v) {
            this.i.sn = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryValueTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dn == null) {
                return null;
            }
            return this.i.dn.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dn = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryLabelText", {
        /**
         * Gets or sets the units text for the data legend.
        */
        get: function () {
            return this.i.lf;
        },
        set: function (v) {
            this.i.lf = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryLabelTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sk);
        },
        set: function (v) {
            this.i.sk = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryLabelTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dk == null) {
                return null;
            }
            return this.i.dk.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dk = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryUnitsText", {
        /**
         * Gets or sets the units text for the data legend.
        */
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryUnitsTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sm);
        },
        set: function (v) {
            this.i.sm = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipSummaryUnitsTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dm == null) {
                return null;
            }
            return this.i.dm.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dm = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipBadgeMarginBottom", {
        get: function () {
            return this.i.ti ? this.i.ti.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipBadgeMargin();
            this.i.ti.bottom = +v;
            this.i.ti = this.i.ti;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipBadgeMarginLeft", {
        get: function () {
            return this.i.ti ? this.i.ti.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipBadgeMargin();
            this.i.ti.left = +v;
            this.i.ti = this.i.ti;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipBadgeMarginRight", {
        get: function () {
            return this.i.ti ? this.i.ti.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipBadgeMargin();
            this.i.ti.right = +v;
            this.i.ti = this.i.ti;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipBadgeMarginTop", {
        get: function () {
            return this.i.ti ? this.i.ti.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipBadgeMargin();
            this.i.ti.top = +v;
            this.i.ti = this.i.ti;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipBadgeMargin = function () {
        if (this.i.ti) {
            return;
        }
        this.i.ti = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipBadgeShape", {
        /**
         * Gets or sets the BadgeShape for the data legend.
        */
        get: function () {
            return this.i.bw;
        },
        set: function (v) {
            this.i.bw = ensureEnum(LegendItemBadgeShape_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsDisplayMode", {
        /**
         * Gets or sets the UnitsMode for the data legend.
        */
        get: function () {
            return this.i.a4;
        },
        set: function (v) {
            this.i.a4 = ensureEnum(DataLegendUnitsMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsText", {
        /**
         * Gets or sets the units text for the data legend.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sp);
        },
        set: function (v) {
            this.i.sp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextMarginBottom", {
        get: function () {
            return this.i.tp ? this.i.tp.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipUnitsTextMargin();
            this.i.tp.bottom = +v;
            this.i.tp = this.i.tp;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextMarginLeft", {
        get: function () {
            return this.i.tp ? this.i.tp.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipUnitsTextMargin();
            this.i.tp.left = +v;
            this.i.tp = this.i.tp;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextMarginRight", {
        get: function () {
            return this.i.tp ? this.i.tp.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipUnitsTextMargin();
            this.i.tp.right = +v;
            this.i.tp = this.i.tp;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextMarginTop", {
        get: function () {
            return this.i.tp ? this.i.tp.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipUnitsTextMargin();
            this.i.tp.top = +v;
            this.i.tp = this.i.tp;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipUnitsTextMargin = function () {
        if (this.i.tp) {
            return;
        }
        this.i.tp = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipUnitsTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dq == null) {
                return null;
            }
            return this.i.dq.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dq = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextMarginBottom", {
        get: function () {
            return this.i.to ? this.i.to.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipTitleTextMargin();
            this.i.to.bottom = +v;
            this.i.to = this.i.to;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextMarginLeft", {
        get: function () {
            return this.i.to ? this.i.to.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipTitleTextMargin();
            this.i.to.left = +v;
            this.i.to = this.i.to;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextMarginRight", {
        get: function () {
            return this.i.to ? this.i.to.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipTitleTextMargin();
            this.i.to.right = +v;
            this.i.to = this.i.to;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextMarginTop", {
        get: function () {
            return this.i.to ? this.i.to.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipTitleTextMargin();
            this.i.to.top = +v;
            this.i.to = this.i.to;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipTitleTextMargin = function () {
        if (this.i.to) {
            return;
        }
        this.i.to = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextColor", {
        /**
         * Gets or sets the display text color.
        */
        get: function () {
            return brushToString(this.i.so);
        },
        set: function (v) {
            this.i.so = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipTitleTextStyle", {
        /**
         * Gets or Sets the style to use for the display text.
        */
        get: function () {
            if (this.i.dp == null) {
                return null;
            }
            return this.i.dp.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dp = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelDisplayMode", {
        /**
         * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
        */
        get: function () {
            return this.i.a0;
        },
        set: function (v) {
            this.i.a0 = ensureEnum(DataLegendLabelMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextColor", {
        /**
         * Gets or sets the units text color.
        */
        get: function () {
            return brushToString(this.i.sj);
        },
        set: function (v) {
            this.i.sj = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextMarginBottom", {
        get: function () {
            return this.i.tl ? this.i.tl.bottom : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipLabelTextMargin();
            this.i.tl.bottom = +v;
            this.i.tl = this.i.tl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextMarginLeft", {
        get: function () {
            return this.i.tl ? this.i.tl.left : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipLabelTextMargin();
            this.i.tl.left = +v;
            this.i.tl = this.i.tl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextMarginRight", {
        get: function () {
            return this.i.tl ? this.i.tl.right : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipLabelTextMargin();
            this.i.tl.right = +v;
            this.i.tl = this.i.tl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextMarginTop", {
        get: function () {
            return this.i.tl ? this.i.tl.top : NaN;
        },
        set: function (v) {
            this.ensureDataToolTipLabelTextMargin();
            this.i.tl.top = +v;
            this.i.tl = this.i.tl;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.ensureDataToolTipLabelTextMargin = function () {
        if (this.i.tl) {
            return;
        }
        this.i.tl = new Thickness(2);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "dataToolTipLabelTextStyle", {
        /**
         * Gets or Sets the style to use for the units text.
        */
        get: function () {
            if (this.i.dj == null) {
                return null;
            }
            return this.i.dj.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.dj = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "domainType", {
        /**
         * Gets the domain type of this chart
        */
        get: function () {
            return this.i.bi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "includedProperties", {
        /**
         * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
        *
        * The `includedProperties` property used to include the properties for the consideration of the category chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     includedProperties="ProductName,Cost" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.includedProperties = ["ProductName", "Cost"];
        * ```
        */
        get: function () {
            return this.i.q;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.q = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "excludedProperties", {
        /**
         * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
        *
        * The `excludedProperties` property used for the property paths that should be excluded from consideration by the category chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     excludedProperties="ID">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.excludedProperties = ["ID", "Discount"];
        * ```
        */
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.o = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "brushes", {
        /**
         * Gets or sets the palette of brushes to use for coloring the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        * Use the `brushes` property to  set the brushes.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       Brushes="#ff0000, #cc0000, #aa0000">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.brushes = ["#ff0000","#00ff00"];
        * ```
        */
        get: function () {
            return fromBrushCollection(this.i.aa);
        },
        set: function (v) {
            this.i.aa = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "outlines", {
        /**
         * Gets or sets the palette of brushes to use for outlines on the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        *  Use the `outlines` property to sets the palette of brushes to use for outlines on the chart series
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     outlines="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        */
        get: function () {
            return fromBrushCollection(this.i.ae);
        },
        set: function (v) {
            this.i.ae = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "actualBrushes", {
        /**
         * Gets the actual palette of brushes to use for coloring the chart series.
        */
        get: function () {
            return fromBrushCollection(this.i.y);
        },
        set: function (v) {
            this.i.y = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "actualOutlines", {
        /**
         * Gets the actual palette of brushes to use for outlines on the chart series.
        */
        get: function () {
            return fromBrushCollection(this.i.z);
        },
        set: function (v) {
            this.i.z = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "isHorizontalZoomEnabled", {
        /**
         * Gets or sets whether the chart can be horizontally zoomed through user interactions.
        *
        * Use the `isHorizontalZoomEnabled` property to allow chart horizontally zoomed .
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       isHorizontalZoomEnabled=true>
        *   </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.isHorizontalZoomEnabled = true;
        * ```
        */
        get: function () {
            return this.i.e0;
        },
        set: function (v) {
            this.i.e0 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "isVerticalZoomEnabled", {
        /**
         * Gets or sets whether the chart can be vertically zoomed through user interactions.
        *
        * Use the `isVerticalZoomEnabled` property to allow chart zoom vertically.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       isVerticalZoomEnabled=true>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.isVerticalZoomEnabled = true;
        * ```
        */
        get: function () {
            return this.i.e6;
        },
        set: function (v) {
            this.i.e6 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "shouldDisplayMockData", {
        /**
         * Gets or sets whether the chart should display mock data when the data source has not been provided, if supported for this type of chart.
        */
        get: function () {
            return this.i.e9;
        },
        set: function (v) {
            this.i.e9 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "shouldUseSkeletonStyleForMockData", {
        /**
         * Gets or sets whether the chart should use a faded skeleton style for mock data.
        */
        get: function () {
            return this.i.fa;
        },
        set: function (v) {
            this.i.fa = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "isSeriesHighlightingEnabled", {
        /**
         * Gets or sets whether the chart can highlight series through user interactions.
         * This property applies to Category Chart and Financial Chart controls.
        */
        get: function () {
            return this.i.e2;
        },
        set: function (v) {
            this.i.e2 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "windowRect", {
        /**
         * Gets or sets the rectangle representing the current scroll and zoom state of the chart.
         * WindowRect is expressed as a Rectangle with coordinates and sizes between 0 and 1.
        *
        * Use `windowRect` property representing the current scroll and zoom state of the chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       WindowRect=[0,0,1,1]>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.windowRect =[0,0,1,1];
        * ```
        */
        get: function () {
            return fromRect(this.i.s7);
        },
        set: function (v) {
            this.i.s7 = toRect(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "viewport", {
        /**
         * Gets a rectangle representing the bounds of the plot area.
        *
        * `viewport` property representing the bounds of the plot area.
        *
        * ```ts
        * let viewport:Rect =  this.chart.viewport;
        * ```
        */
        get: function () {
            return fromRect(this.i.s6);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "chartTitle", {
        /**
         * Gets or sets text to display above the plot area.
        *
        * Use the `chartTitle` property to display the text above the plot area.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     title="This is a Title">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.title= "This is a Title";
        * ```
        */
        get: function () {
            return this.i.oh;
        },
        set: function (v) {
            this.i.oh = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitle", {
        /**
         * Gets or sets text to display below the Title, above the plot area.
        *
        * Use the `subtitle` property to display the text below  and above the plot area.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitle= "This is a subtitle">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.subtitle ="CategoryChart Subtitle" ;
        * ```
        */
        get: function () {
            return this.i.n6;
        },
        set: function (v) {
            this.i.n6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "titleAlignment", {
        /**
         * Gets or sets horizontal alignment which determines the title position, relative to the left and right edges of the control.
        *
        * Use the `titleAlignment` property for the horizontal alignment of the title.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     titleAlignment= "center">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleAlignment = HorizontalAlignment.Center;
        * ```
        */
        get: function () {
            return this.i.ro;
        },
        set: function (v) {
            this.i.ro = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "subtitleAlignment", {
        /**
         * Gets or sets horizontal alignment which determines the subtitle position, relative to the left and right edges of the control.
        *
        * Use the `subtitleAlignment` property to Gets or sets horizontal alignment.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleAlignment= "center">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleAlignment = HorizontalAlignment.Right;
        * ```
        */
        get: function () {
            return this.i.rn;
        },
        set: function (v) {
            this.i.rn = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "unknownValuePlotting", {
        /**
         * Gets or sets the behavior that determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        *
        * Use the `unknownValuePlotting` property to determines the behavior that how unknown values will be plotted on the chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       unknownValuePlotting= "dontPlot">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.unknownValuePlotting =UnknownValuePlotting.DontPlot;
        * ```
        */
        get: function () {
            return this.i.c4;
        },
        set: function (v) {
            this.i.c4 = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "resolution", {
        /**
         * Gets or sets the rendering resolution for all series in this chart.
         * Where n = Resolution, for every n horizontal pixels, combine all items into a single data point.  When Resolution = 0, all data points will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
        *
        * Use the `resolution` property if the callouts should be display.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     resolution= 2>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *   this.chart.resolution = 2 ;
        * ```
        */
        get: function () {
            return this.i.hn;
        },
        set: function (v) {
            this.i.hn = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "thickness", {
        /**
         * Gets or sets the thickness for all series in this chart. Depending on the ChartType, this can be the main brush used, or just the outline.
        *
        * Use the `thickness` property for the thickness of all the series in this chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     thickness=5>
        * </igx-category-chart>
        * ```
        */
        get: function () {
            return this.i.ht;
        },
        set: function (v) {
            this.i.ht = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "outlineMode", {
        /**
         * Gets or sets the OutlineMode for all series in this chart.
        */
        get: function () {
            return this.i.cm;
        },
        set: function (v) {
            this.i.cm = ensureEnum(SeriesOutlineMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerOutlineMode", {
        /**
         * Gets or sets the MarkerOutlineMode for all series that support markers in this chart.
        */
        get: function () {
            return this.i.b3;
        },
        set: function (v) {
            this.i.b3 = ensureEnum(MarkerOutlineMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerFillMode", {
        /**
         * Gets or sets the MarkerFillMode for all series that support markers in this chart.
        */
        get: function () {
            return this.i.b1;
        },
        set: function (v) {
            this.i.b1 = ensureEnum(MarkerFillMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerFillOpacity", {
        /**
         * Gets or sets the Marker Fill Opacity for all series that support markers in this chart.
        */
        get: function () {
            return this.i.hg;
        },
        set: function (v) {
            this.i.hg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerThickness", {
        /**
         * Gets or sets the Marker Thickness for all series that support markers in this chart.
        */
        get: function () {
            return this.i.hh;
        },
        set: function (v) {
            this.i.hh = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerTypes", {
        /**
         * Gets or sets the marker shapes used for indicating location of data points in this chart.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        */
        get: function () {
            if (this._markerTypes === null) {
                var coll = new IgxMarkerTypeCollection();
                var innerColl = this.i.b8;
                if (!innerColl) {
                    innerColl = new MarkerTypeCollection_internal();
                }
                this._markerTypes = coll._fromInner(innerColl);
                this.i.b8 = innerColl;
            }
            return this._markerTypes;
        },
        set: function (v) {
            if (this._markerTypes !== null) {
                this._markerTypes._setSyncTarget(null);
                this._markerTypes = null;
            }
            var coll = new IgxMarkerTypeCollection();
            this._markerTypes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(MarkerType_$type);
            var innerColl = this.i.b8;
            if (!innerColl) {
                innerColl = new MarkerTypeCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._markerTypes._setSyncTarget(syncColl);
            this.i.b8 = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerAutomaticBehavior", {
        /**
         * Gets or sets the default marker type for all series plotted in this chart.
         * This property is ignored when the MarkerTypes property is set
        */
        get: function () {
            return this.i.bz;
        },
        set: function (v) {
            this.i.bz = ensureEnum(MarkerAutomaticBehavior_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerBrushes", {
        /**
         * Gets or sets the palette of brushes used for rendering fill area of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        *
        * `markerBrushes` property used for rendering fill area of data point markers.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerBrushes="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.markerBrushes=[ "#ff0000", "#ffff00", "#00ffff" ];
        * ```
        */
        get: function () {
            return fromBrushCollection(this.i.ac);
        },
        set: function (v) {
            this.i.ac = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerOutlines", {
        /**
         * Gets or sets the palette of brushes used for rendering outlines of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        *
        * `markerOutlines` property used for rendering outlines of data point markers.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerOutlines="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.markerOutlines= ["#ff0000", "#ffff00", "#00ffff"] ;
        * ```
        */
        get: function () {
            return fromBrushCollection(this.i.ad);
        },
        set: function (v) {
            this.i.ad = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "markerMaxCount", {
        /**
         * Gets or sets the maximum number of markers displayed in the plot area of the chart.
        *
        * `markerMaxCount` property used to display maximum number of markers in the plot area of the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerMaxCount=100 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.markerMaxCount = 100 ;
        * ```
        */
        get: function () {
            return this.i.ip;
        },
        set: function (v) {
            this.i.ip = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "areaFillOpacity", {
        /**
         * Gets or sets the fill opacity for all series that have area visuals in this chart.
         * For example, Area, SplineArea, Column chart types
        */
        get: function () {
            return this.i.g1;
        },
        set: function (v) {
            this.i.g1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "animateSeriesWhenAxisRangeChanges", {
        /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
        get: function () {
            return this.i.eh;
        },
        set: function (v) {
            this.i.eh = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "trendLineBrushes", {
        /**
         * Gets or sets the palette of brushes to used for coloring trend lines in this chart.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        * Use the `trendLineBrushes` property for coloring trend lines in the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     trendLineBrushes="#ff0000,#aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineBrushes=["#ff0000", "#ffff00", "#00ffff"]	;
        * ```
        */
        get: function () {
            return fromBrushCollection(this.i.ag);
        },
        set: function (v) {
            this.i.ag = toBrushCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the formula used for calculating trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        *
        * Use the `trendLineType` property for calculating trend lines.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       trendLineType= "cubicFit">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineType = TrendLineType.CubicFit;
        * ```
        */
        get: function () {
            return this.i.c2;
        },
        set: function (v) {
            this.i.c2 = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        *
        * Use the `trendLineThickness` property for the thickness of the trend lines in the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     trendLineThickness= 2>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineThickness=2;
        * ```
        */
        get: function () {
            return this.i.hz;
        },
        set: function (v) {
            this.i.hz = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "alignsGridLinesToPixels", {
        /**
         * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
        *
        * Use `alignsGridLinesToPixels` propert to indicat whether grid and tick lines are aligned to device pixels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     AlignsGridLinesToPixels="true">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.alignsGridLinesToPixels= true;
        * ```
        */
        get: function () {
            return this.i.eg;
        },
        set: function (v) {
            this.i.eg = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "plotAreaMarginLeft", {
        /**
         * Margin applied to the Left of the plot area.
        */
        get: function () {
            return this.i.hk;
        },
        set: function (v) {
            this.i.hk = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "plotAreaMarginTop", {
        /**
         * Margin applied to the Top of the plot area.
        */
        get: function () {
            return this.i.hm;
        },
        set: function (v) {
            this.i.hm = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "plotAreaMarginRight", {
        /**
         * Margin applied to the right of the plot area.
        */
        get: function () {
            return this.i.hl;
        },
        set: function (v) {
            this.i.hl = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "plotAreaMarginBottom", {
        /**
         * Margin applied below the plot area.
        */
        get: function () {
            return this.i.hj;
        },
        set: function (v) {
            this.i.hj = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "computedPlotAreaMarginMode", {
        /**
         * Gets or sets mode to use for automatically calculating the plot area margin.
        */
        get: function () {
            return this.i.ao;
        },
        set: function (v) {
            this.i.ao = ensureEnum(ComputedPlotAreaMarginMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPlotAreaMarginHorizontalMode", {
        /**
         * Gets or sets horizontal mode to use for automatically calculating the plot area margin based ont the series.
        */
        get: function () {
            return this.i.co;
        },
        set: function (v) {
            this.i.co = ensureEnum(SeriesPlotAreaMarginHorizontalMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPlotAreaMarginVerticalMode", {
        /**
         * Gets or sets vertical mode to use for automatically calculating the plot area margin based ont the series.
        */
        get: function () {
            return this.i.cq;
        },
        set: function (v) {
            this.i.cq = ensureEnum(SeriesPlotAreaMarginVerticalMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "highlightingMode", {
        /**
         * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
        */
        get: function () {
            return this.i.ck;
        },
        set: function (v) {
            this.i.ck = ensureEnum(SeriesHighlightingMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "highlightingBehavior", {
        /**
         * Gets or sets the highlighting Behavior to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
        */
        get: function () {
            return this.i.ci;
        },
        set: function (v) {
            this.i.ci = ensureEnum(SeriesHighlightingBehavior_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "legendHighlightingMode", {
        /**
         * Gets or sets the highlighting mode to use for the legend linked to the component, when supported.
        */
        get: function () {
            return this.i.br;
        },
        set: function (v) {
            this.i.br = ensureEnum(LegendHighlightingMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "legendItemBadgeShape", {
        /**
         * Gets or sets the type of legend badges representing all series displayed in a legend linked to this component
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
        */
        get: function () {
            return this.i.bx;
        },
        set: function (v) {
            this.i.bx = ensureEnum(LegendItemBadgeShape_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "legendItemBadgeMode", {
        /**
         * Gets or sets the mode of legend badges representing all series displayed in a legend linked to this component.
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
        */
        get: function () {
            return this.i.bt;
        },
        set: function (v) {
            this.i.bt = ensureEnum(LegendItemBadgeMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "trendLinePeriod", {
        get: function () {
            return this.i.ir;
        },
        set: function (v) {
            this.i.ir = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "toolTipType", {
        /**
         * Gets or sets the style of tooltip to be displayed.
        */
        get: function () {
            return this.i.c0;
        },
        set: function (v) {
            this.i.c0 = ensureEnum(ToolTipType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsDisplayMode", {
        /**
         * Gets or sets the crosshairs to be displayed.
        */
        get: function () {
            return this.i.aq;
        },
        set: function (v) {
            this.i.aq = ensureEnum(CrosshairsDisplayMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsSnapToData", {
        /**
         * Gets or sets whether crosshairs will snap to the nearest data point.
        */
        get: function () {
            return this.i.em;
        },
        set: function (v) {
            this.i.em = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsLineVerticalStroke", {
        /**
         * Gets or sets the color to apply to vertical crosshairs line.
        */
        get: function () {
            return brushToString(this.i.sh);
        },
        set: function (v) {
            this.i.sh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsLineThickness", {
        /**
         * Gets or sets thickness of crosshairs lines.
        */
        get: function () {
            return this.i.g3;
        },
        set: function (v) {
            this.i.g3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsLineHorizontalStroke", {
        /**
         * Gets or sets the color to apply to horizontal crosshairs line.
        */
        get: function () {
            return brushToString(this.i.sg);
        },
        set: function (v) {
            this.i.sg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationEnabled", {
        /**
         * Gets or sets whether annotations are shown along the axis for crosshair values
        */
        get: function () {
            return this.i.el;
        },
        set: function (v) {
            this.i.el = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationXAxisBackground", {
        /**
         * Gets or sets the background of crosshair annotation on x-axis.
        */
        get: function () {
            return brushToString(this.i.sc);
        },
        set: function (v) {
            this.i.sc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationYAxisBackground", {
        /**
         * Gets or sets the background of crosshair annotation on y-axis.
        */
        get: function () {
            return brushToString(this.i.se);
        },
        set: function (v) {
            this.i.se = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationXAxisTextColor", {
        /**
         * Gets or sets the text color of crosshair annotation on x-axis.
        */
        get: function () {
            return brushToString(this.i.sd);
        },
        set: function (v) {
            this.i.sd = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationYAxisTextColor", {
        /**
         * Gets or sets the text color of crosshair annotation on y-axis.
        */
        get: function () {
            return brushToString(this.i.sf);
        },
        set: function (v) {
            this.i.sf = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationXAxisPrecision", {
        /**
         * Gets or sets precision on interpolated values of crosshairs on x-axis.
        */
        get: function () {
            return this.i.ij;
        },
        set: function (v) {
            this.i.ij = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "crosshairsAnnotationYAxisPrecision", {
        /**
         * Gets or sets precision on interpolated values of crosshairs on y-axis.
        */
        get: function () {
            return this.i.ik;
        },
        set: function (v) {
            this.i.ik = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "shouldAvoidAxisAnnotationCollisions", {
        /**
         * Gets or sets whether annotations for the final value of each series is displayed on the axis.
        */
        get: function () {
            return this.i.e8;
        },
        set: function (v) {
            this.i.e8 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "finalValueAnnotationsVisible", {
        /**
         * Gets or sets whether annotations for the final value of each series is displayed on the axis.
        */
        get: function () {
            return this.i.es;
        },
        set: function (v) {
            this.i.es = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "finalValueAnnotationsBackground", {
        /**
         * Gets or sets the background of final value annotation.
        */
        get: function () {
            return brushToString(this.i.sr);
        },
        set: function (v) {
            this.i.sr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "finalValueAnnotationsTextColor", {
        /**
         * Gets or sets the text color of final value annotation.
        */
        get: function () {
            return brushToString(this.i.ss);
        },
        set: function (v) {
            this.i.ss = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "finalValueAnnotationsPrecision", {
        /**
         * Gets or sets precision on final value annotation.
        */
        get: function () {
            return this.i.io;
        },
        set: function (v) {
            this.i.io = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsVisible", {
        /**
         * Gets or sets if callouts should be displayed.
        */
        get: function () {
            return this.i.ek;
        },
        set: function (v) {
            this.i.ek = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutStyleUpdatingEventEnabled", {
        /**
         * Gets or sets if event annotations should be displayed.
        */
        get: function () {
            return this.i.ej;
        },
        set: function (v) {
            this.i.ej = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsAllowedPositions", {
        /**
         * Gets or sets the allowed positions that the callout layer is allowed to use.
        */
        get: function () {
            if (this._calloutsAllowedPositions === null) {
                var coll = new IgxCalloutPlacementPositionsCollection();
                var innerColl = this.i.ai;
                if (!innerColl) {
                    innerColl = new CalloutPlacementPositionsCollection_internal();
                }
                this._calloutsAllowedPositions = coll._fromInner(innerColl);
                this.i.ai = innerColl;
            }
            return this._calloutsAllowedPositions;
        },
        set: function (v) {
            if (this._calloutsAllowedPositions !== null) {
                this._calloutsAllowedPositions._setSyncTarget(null);
                this._calloutsAllowedPositions = null;
            }
            var coll = new IgxCalloutPlacementPositionsCollection();
            this._calloutsAllowedPositions = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(CalloutPlacementPositions_$type);
            var innerColl = this.i.ai;
            if (!innerColl) {
                innerColl = new CalloutPlacementPositionsCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._calloutsAllowedPositions._setSyncTarget(syncColl);
            this.i.ai = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsXMemberPath", {
        /**
         * Gets or sets the member path of the X data for the callouts.
        */
        get: function () {
            return this.i.j1;
        },
        set: function (v) {
            this.i.j1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsYMemberPath", {
        /**
         * Gets or sets the member path of the Y data for the callouts.
        */
        get: function () {
            return this.i.j3;
        },
        set: function (v) {
            this.i.j3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsLabelMemberPath", {
        /**
         * Gets or sets the member path of the label data for the callouts.
        */
        get: function () {
            return this.i.jx;
        },
        set: function (v) {
            this.i.jx = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutsContentMemberPath", {
        /**
         * Gets or sets the member path of the content data for the callouts.
        */
        get: function () {
            return this.i.ju;
        },
        set: function (v) {
            this.i.ju = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarMode", {
        /**
         * Gets or sets the horizontal scrollbar mode to use for the series viewer.
        */
        get: function () {
            return this.i.cv;
        },
        set: function (v) {
            this.i.cv = ensureEnum(SeriesViewerScrollbarMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarMode", {
        /**
         * Gets or sets the vertical scrollbar mode to use for the series viewer.
        */
        get: function () {
            return this.i.cw;
        },
        set: function (v) {
            this.i.cw = ensureEnum(SeriesViewerScrollbarMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarPosition", {
        /**
         * Gets or sets the position to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.cs;
        },
        set: function (v) {
            this.i.cs = ensureEnum(SeriesViewerHorizontalScrollbarPosition_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarPosition", {
        /**
         * Gets or sets the position to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.cy;
        },
        set: function (v) {
            this.i.cy = ensureEnum(SeriesViewerVerticalScrollbarPosition_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarFill", {
        /**
         * Gets or sets the fill to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return brushToString(this.i.sx);
        },
        set: function (v) {
            this.i.sx = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarOutline", {
        /**
         * Gets or sets the outline to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return brushToString(this.i.sy);
        },
        set: function (v) {
            this.i.sy = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarStrokeThickness", {
        /**
         * Gets or sets the stroke thickness to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.hc;
        },
        set: function (v) {
            this.i.hc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarMaxOpacity", {
        /**
         * Gets or sets the max opacity to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            this.i.hb = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarCornerRadius", {
        /**
         * Gets or sets the corner radius to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.g8;
        },
        set: function (v) {
            this.i.g8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarHeight", {
        /**
         * Gets or sets the height to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.g9;
        },
        set: function (v) {
            this.i.g9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarInset", {
        /**
         * Gets or sets the inset distance to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.ha;
        },
        set: function (v) {
            this.i.ha = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarTrackStartInset", {
        /**
         * Gets or sets the track start inset to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.he;
        },
        set: function (v) {
            this.i.he = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarTrackEndInset", {
        /**
         * Gets or sets the track end inset to use for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.hd;
        },
        set: function (v) {
            this.i.hd = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "horizontalViewScrollbarShouldAddAutoTrackInsets", {
        /**
         * Gets or sets whether to use automatic track insets for the horizontal scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.eu;
        },
        set: function (v) {
            this.i.eu = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarFill", {
        /**
         * Gets or sets the fill to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return brushToString(this.i.s2);
        },
        set: function (v) {
            this.i.s2 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarOutline", {
        /**
         * Gets or sets the outline to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return brushToString(this.i.s3);
        },
        set: function (v) {
            this.i.s3 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarStrokeThickness", {
        /**
         * Gets or sets the stroke thickness to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h3;
        },
        set: function (v) {
            this.i.h3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarMaxOpacity", {
        /**
         * Gets or sets the max opacity to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h2;
        },
        set: function (v) {
            this.i.h2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarCornerRadius", {
        /**
         * Gets or sets the corner radius to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h0;
        },
        set: function (v) {
            this.i.h0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarWidth", {
        /**
         * Gets or sets the width to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h6;
        },
        set: function (v) {
            this.i.h6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarInset", {
        /**
         * Gets or sets the inset distance to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h1;
        },
        set: function (v) {
            this.i.h1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarTrackStartInset", {
        /**
         * Gets or sets the track start inset to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h5;
        },
        set: function (v) {
            this.i.h5 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarTrackEndInset", {
        /**
         * Gets or sets the track end inset to use for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.h4;
        },
        set: function (v) {
            this.i.h4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "verticalViewScrollbarShouldAddAutoTrackInsets", {
        /**
         * Gets or sets whether to use automatic track insets for the vertical scrollbar in the component, when enabled.
        */
        get: function () {
            return this.i.fb;
        },
        set: function (v) {
            this.i.fb = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.findByName = function (name) {
        if (this.dataToolTipValueFormatSpecifiers != null && arrayFindByName(this.dataToolTipValueFormatSpecifiers, name)) {
            return arrayFindByName(this.dataToolTipValueFormatSpecifiers, name);
        }
        if (this.dataToolTipHeaderFormatSpecifiers != null && arrayFindByName(this.dataToolTipHeaderFormatSpecifiers, name)) {
            return arrayFindByName(this.dataToolTipHeaderFormatSpecifiers, name);
        }
        if (this.legend && this.legend.name && this.legend.name == name) {
            return this.legend;
        }
        if (this.markerTypes != null && this.markerTypes.findByName && this.markerTypes.findByName(name)) {
            return this.markerTypes.findByName(name);
        }
        if (this.calloutsAllowedPositions != null && this.calloutsAllowedPositions.findByName && this.calloutsAllowedPositions.findByName(name)) {
            return this.calloutsAllowedPositions.findByName(name);
        }
        return null;
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgxDomainChartComponent.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DomainChartComponent");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    /**
 * Provides a container for this control

*
* `provideContainer` method provide container for the control.
*
* ```ts
*     this.chart.provideContainer("Container");
* ```
*/
    IgxDomainChartComponent.prototype.provideContainer = function (container) {
        this.i.provideContainer(container);
    };
    /**
     * Destroy this control
    
    *
    * Use the `destroy` property to destroy the chart.
    *
    * ```ts
    * this.chart.destroy();
    * ```
    */
    IgxDomainChartComponent.prototype.destroy = function () {
        this.i.destroy();
    };
    /**
     * Called when the control has been resized.
    
    *
    * `notifyResized` method Called when the control has been resized.
    *
    * ```ts
    * this.chart.notifyResized();
    * ```
    */
    IgxDomainChartComponent.prototype.notifyResized = function () {
        this.i.notifyResized();
    };
    IgxDomainChartComponent.prototype.notifyVisualPropertiesChanged = function () {
        this.i.qj();
    };
    /**
     * Forces any pending refresh to the chart to be finished.
    
    *
    * Method `flush` used to Forces any pending deferred work to render on the chart before continuing.
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    IgxDomainChartComponent.prototype.flush = function () {
        this.i.pq();
    };
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * Use the `hideToolTip` method to hide the active tooltip.
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    IgxDomainChartComponent.prototype.hideToolTip = function () {
        this.i.py();
    };
    /**
     * Replays transition-in animation on all series in the chart.
    
    */
    IgxDomainChartComponent.prototype.replayTransitionIn = function () {
        this.i.ra();
    };
    IgxDomainChartComponent.prototype.notifySetItem = function (source_, index, oldItem, newItem) {
        this.i.qi(source_, index, oldItem, newItem);
    };
    /**
     * Used to manually notify the chart that the data source has reset or cleared its items.
    
    *
    * Use `notifyClearItems` method to notifies the chart that the items have been cleared from an associated data source.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    IgxDomainChartComponent.prototype.notifyClearItems = function (source_) {
        this.i.qe(source_);
    };
    IgxDomainChartComponent.prototype.notifyInsertItem = function (source_, index, newItem) {
        this.i.qf(source_, index, newItem);
    };
    IgxDomainChartComponent.prototype.notifyRemoveItem = function (source_, index, oldItem) {
        this.i.qg(source_, index, oldItem);
    };
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesAdded", {
        /**
         * Event raised when a series is initialized and added to this chart.
        *
        * `SeriesAdded` event raised when a series is initialized and added to this chart.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesAdded)="CategoryChart_SeriesAdded()"
        *      >
        * </igx-category-chart>
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesAdded == null) {
                this._seriesAdded = new EventEmitter();
                this.i.seriesAdded = delegateCombine(this.i.seriesAdded, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxChartSeriesEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesAdded) {
                            _this.beforeSeriesAdded(_this, outerArgs);
                        }
                        _this._seriesAdded.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesAdded;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesRemoved", {
        /**
         * Event raised when a series is removed from this chart.
        *
        * `SeriesRemoved` event raised when a series is removed from this chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesRemoved)="CategoryChart_seriesRemoved()">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  CategoryChart_seriesRemoved(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesRemoved == null) {
                this._seriesRemoved = new EventEmitter();
                this.i.seriesRemoved = delegateCombine(this.i.seriesRemoved, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxChartSeriesEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesRemoved) {
                            _this.beforeSeriesRemoved(_this, outerArgs);
                        }
                        _this._seriesRemoved.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesRemoved;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPointerEnter", {
        /**
         * Occurs when the pointer enters a Series.
        *
        * `SeriesPointerEnter` event raised when the pointer enters a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerEnter)="CategoryChart_seriesPointerEnter()" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * CategoryChart_seriesPointerEnter(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesPointerEnter == null) {
                this._seriesPointerEnter = new EventEmitter();
                this.i.seriesPointerEnter = delegateCombine(this.i.seriesPointerEnter, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesPointerEnter) {
                            _this.beforeSeriesPointerEnter(_this, outerArgs);
                        }
                        _this._seriesPointerEnter.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerEnter;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPointerLeave", {
        /**
         * Occurs when the pointer leaves a Series.
        *
        * `SeriesPointerLeave` event raised when the pointer leaves a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerLeave)= "CategoryChart_seriesPointerLeave()" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * CategoryChart_seriesPointerLeave(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesPointerLeave == null) {
                this._seriesPointerLeave = new EventEmitter();
                this.i.seriesPointerLeave = delegateCombine(this.i.seriesPointerLeave, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesPointerLeave) {
                            _this.beforeSeriesPointerLeave(_this, outerArgs);
                        }
                        _this._seriesPointerLeave.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerLeave;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPointerMove", {
        /**
         * Occurs when the pointer moves over a Series.
        *
        * `SeriesPointerMove` event raised when the pointer moves over a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *        (seriesPointerMove)="CategoryChart_seriesPointerMove()">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  CategoryChart_seriesPointerMove(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesPointerMove == null) {
                this._seriesPointerMove = new EventEmitter();
                this.i.seriesPointerMove = delegateCombine(this.i.seriesPointerMove, function (o, e) {
                    var outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSeriesPointerMove) {
                        _this.beforeSeriesPointerMove(_this, outerArgs);
                    }
                    _this._seriesPointerMove.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesPointerMove;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPointerDown", {
        /**
         * Occurs when the pointer is pressed down over a Series.
        *
        * `SeriesPointerDown` event raised when the pointer is pressed down over a Series
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerDown)="CategoryChart_seriesPointerDown()" >
        * </igx-category-chart>
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesPointerDown == null) {
                this._seriesPointerDown = new EventEmitter();
                this.i.seriesPointerDown = delegateCombine(this.i.seriesPointerDown, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesPointerDown) {
                            _this.beforeSeriesPointerDown(_this, outerArgs);
                        }
                        _this._seriesPointerDown.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerDown;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "seriesPointerUp", {
        /**
         * Occurs when the pointer is released over a Series.
        *
        * `SeriesPointerUp` event raised when the pointer is released over a Series.
        *
        * ```ts
        *  CategoryChart_seriesPointerUp(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerUp)="CategoryChart_seriesPointerUp()" >
        * </igx-category-chart>
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesPointerUp == null) {
                this._seriesPointerUp = new EventEmitter();
                this.i.seriesPointerUp = delegateCombine(this.i.seriesPointerUp, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesPointerUp) {
                            _this.beforeSeriesPointerUp(_this, outerArgs);
                        }
                        _this._seriesPointerUp.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerUp;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutStyleUpdating", {
        /**
         * Occurs when the style of a callout is updated.
        */
        get: function () {
            var _this = this;
            if (this._calloutStyleUpdating == null) {
                this._calloutStyleUpdating = new EventEmitter();
                this.i.calloutStyleUpdating = delegateCombine(this.i.calloutStyleUpdating, function (o, e) {
                    var outerArgs = new IgxCalloutStyleUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeCalloutStyleUpdating) {
                        _this.beforeCalloutStyleUpdating(_this, outerArgs);
                    }
                    _this._calloutStyleUpdating.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._calloutStyleUpdating;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartComponent.prototype, "calloutRenderStyleUpdating", {
        /**
         * Occurs when the style of a callout is updated.
        */
        get: function () {
            var _this = this;
            if (this._calloutRenderStyleUpdating == null) {
                this._calloutRenderStyleUpdating = new EventEmitter();
                this.i.calloutRenderStyleUpdating = delegateCombine(this.i.calloutRenderStyleUpdating, function (o, e) {
                    var outerArgs = new IgxCalloutRenderStyleUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeCalloutRenderStyleUpdating) {
                        _this.beforeCalloutRenderStyleUpdating(_this, outerArgs);
                    }
                    _this._calloutRenderStyleUpdating.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._calloutRenderStyleUpdating;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartComponent.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    IgxDomainChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: IgxDomainChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxDomainChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.14", type: IgxDomainChartComponent, selector: "ng-component", inputs: { tooltipTemplate: "tooltipTemplate", tooltipTemplates: "tooltipTemplates", legend: "legend", calloutsDataSource: "calloutsDataSource", pixelScalingRatio: "pixelScalingRatio", titleLeftMargin: "titleLeftMargin", titleRightMargin: "titleRightMargin", titleTopMargin: "titleTopMargin", titleBottomMargin: "titleBottomMargin", subtitleLeftMargin: "subtitleLeftMargin", subtitleTopMargin: "subtitleTopMargin", subtitleRightMargin: "subtitleRightMargin", subtitleBottomMargin: "subtitleBottomMargin", subtitleTextColor: "subtitleTextColor", titleTextColor: "titleTextColor", leftMargin: "leftMargin", topMargin: "topMargin", rightMargin: "rightMargin", bottomMargin: "bottomMargin", transitionDuration: "transitionDuration", transitionEasingFunction: "transitionEasingFunction", subtitleTextStyle: "subtitleTextStyle", titleTextStyle: "titleTextStyle", dataToolTipGroupingMode: "dataToolTipGroupingMode", dataToolTipPositionOffsetX: "dataToolTipPositionOffsetX", dataToolTipPositionOffsetY: "dataToolTipPositionOffsetY", dataToolTipDefaultPositionOffsetX: "dataToolTipDefaultPositionOffsetX", dataToolTipDefaultPositionOffsetY: "dataToolTipDefaultPositionOffsetY", dataToolTipGroupedPositionModeX: "dataToolTipGroupedPositionModeX", dataToolTipGroupedPositionModeY: "dataToolTipGroupedPositionModeY", dataToolTipShouldUpdateWhenSeriesDataChanges: "dataToolTipShouldUpdateWhenSeriesDataChanges", dataToolTipIncludedSeries: "dataToolTipIncludedSeries", dataToolTipExcludedSeries: "dataToolTipExcludedSeries", dataToolTipIncludedColumns: "dataToolTipIncludedColumns", dataToolTipExcludedColumns: "dataToolTipExcludedColumns", dataToolTipValueFormatAbbreviation: "dataToolTipValueFormatAbbreviation", dataToolTipValueFormatMaxFractions: "dataToolTipValueFormatMaxFractions", dataToolTipValueFormatMinFractions: "dataToolTipValueFormatMinFractions", dataToolTipValueFormatMode: "dataToolTipValueFormatMode", dataToolTipValueFormatCulture: "dataToolTipValueFormatCulture", dataToolTipValueFormatUseGrouping: "dataToolTipValueFormatUseGrouping", dataToolTipValueFormatString: "dataToolTipValueFormatString", dataToolTipValueFormatSpecifiers: "dataToolTipValueFormatSpecifiers", dataToolTipValueRowMarginBottom: "dataToolTipValueRowMarginBottom", dataToolTipValueRowMarginLeft: "dataToolTipValueRowMarginLeft", dataToolTipValueRowMarginRight: "dataToolTipValueRowMarginRight", dataToolTipValueRowMarginTop: "dataToolTipValueRowMarginTop", dataToolTipValueRowVisible: "dataToolTipValueRowVisible", dataToolTipValueTextWhenMissingData: "dataToolTipValueTextWhenMissingData", dataToolTipValueTextUseSeriesColors: "dataToolTipValueTextUseSeriesColors", dataToolTipValueTextMarginBottom: "dataToolTipValueTextMarginBottom", dataToolTipValueTextMarginLeft: "dataToolTipValueTextMarginLeft", dataToolTipValueTextMarginRight: "dataToolTipValueTextMarginRight", dataToolTipValueTextMarginTop: "dataToolTipValueTextMarginTop", dataToolTipValueTextColor: "dataToolTipValueTextColor", dataToolTipValueTextStyle: "dataToolTipValueTextStyle", dataToolTipHeaderFormatString: "dataToolTipHeaderFormatString", dataToolTipHeaderFormatSpecifiers: "dataToolTipHeaderFormatSpecifiers", dataToolTipHeaderFormatCulture: "dataToolTipHeaderFormatCulture", dataToolTipHeaderFormatDate: "dataToolTipHeaderFormatDate", dataToolTipHeaderFormatTime: "dataToolTipHeaderFormatTime", dataToolTipHeaderText: "dataToolTipHeaderText", dataToolTipHeaderTextColor: "dataToolTipHeaderTextColor", dataToolTipHeaderTextMarginBottom: "dataToolTipHeaderTextMarginBottom", dataToolTipHeaderTextMarginLeft: "dataToolTipHeaderTextMarginLeft", dataToolTipHeaderTextMarginRight: "dataToolTipHeaderTextMarginRight", dataToolTipHeaderTextMarginTop: "dataToolTipHeaderTextMarginTop", dataToolTipHeaderRowMarginBottom: "dataToolTipHeaderRowMarginBottom", dataToolTipHeaderRowMarginLeft: "dataToolTipHeaderRowMarginLeft", dataToolTipHeaderRowMarginRight: "dataToolTipHeaderRowMarginRight", dataToolTipHeaderRowMarginTop: "dataToolTipHeaderRowMarginTop", dataToolTipHeaderRowVisible: "dataToolTipHeaderRowVisible", dataToolTipHeaderTextStyle: "dataToolTipHeaderTextStyle", dataToolTipSummaryTitleTextColor: "dataToolTipSummaryTitleTextColor", dataToolTipSummaryTitleTextStyle: "dataToolTipSummaryTitleTextStyle", dataToolTipSummaryType: "dataToolTipSummaryType", dataToolTipSummaryTitleText: "dataToolTipSummaryTitleText", dataToolTipSummaryTitleTextMarginBottom: "dataToolTipSummaryTitleTextMarginBottom", dataToolTipSummaryTitleTextMarginLeft: "dataToolTipSummaryTitleTextMarginLeft", dataToolTipSummaryTitleTextMarginRight: "dataToolTipSummaryTitleTextMarginRight", dataToolTipSummaryTitleTextMarginTop: "dataToolTipSummaryTitleTextMarginTop", dataToolTipSummaryRowMarginBottom: "dataToolTipSummaryRowMarginBottom", dataToolTipSummaryRowMarginLeft: "dataToolTipSummaryRowMarginLeft", dataToolTipSummaryRowMarginRight: "dataToolTipSummaryRowMarginRight", dataToolTipSummaryRowMarginTop: "dataToolTipSummaryRowMarginTop", dataToolTipSummaryValueTextColor: "dataToolTipSummaryValueTextColor", dataToolTipSummaryValueTextStyle: "dataToolTipSummaryValueTextStyle", dataToolTipSummaryLabelText: "dataToolTipSummaryLabelText", dataToolTipSummaryLabelTextColor: "dataToolTipSummaryLabelTextColor", dataToolTipSummaryLabelTextStyle: "dataToolTipSummaryLabelTextStyle", dataToolTipSummaryUnitsText: "dataToolTipSummaryUnitsText", dataToolTipSummaryUnitsTextColor: "dataToolTipSummaryUnitsTextColor", dataToolTipSummaryUnitsTextStyle: "dataToolTipSummaryUnitsTextStyle", dataToolTipBadgeMarginBottom: "dataToolTipBadgeMarginBottom", dataToolTipBadgeMarginLeft: "dataToolTipBadgeMarginLeft", dataToolTipBadgeMarginRight: "dataToolTipBadgeMarginRight", dataToolTipBadgeMarginTop: "dataToolTipBadgeMarginTop", dataToolTipBadgeShape: "dataToolTipBadgeShape", dataToolTipUnitsDisplayMode: "dataToolTipUnitsDisplayMode", dataToolTipUnitsText: "dataToolTipUnitsText", dataToolTipUnitsTextColor: "dataToolTipUnitsTextColor", dataToolTipUnitsTextMarginBottom: "dataToolTipUnitsTextMarginBottom", dataToolTipUnitsTextMarginLeft: "dataToolTipUnitsTextMarginLeft", dataToolTipUnitsTextMarginRight: "dataToolTipUnitsTextMarginRight", dataToolTipUnitsTextMarginTop: "dataToolTipUnitsTextMarginTop", dataToolTipUnitsTextStyle: "dataToolTipUnitsTextStyle", dataToolTipTitleTextMarginBottom: "dataToolTipTitleTextMarginBottom", dataToolTipTitleTextMarginLeft: "dataToolTipTitleTextMarginLeft", dataToolTipTitleTextMarginRight: "dataToolTipTitleTextMarginRight", dataToolTipTitleTextMarginTop: "dataToolTipTitleTextMarginTop", dataToolTipTitleTextColor: "dataToolTipTitleTextColor", dataToolTipTitleTextStyle: "dataToolTipTitleTextStyle", dataToolTipLabelDisplayMode: "dataToolTipLabelDisplayMode", dataToolTipLabelTextColor: "dataToolTipLabelTextColor", dataToolTipLabelTextMarginBottom: "dataToolTipLabelTextMarginBottom", dataToolTipLabelTextMarginLeft: "dataToolTipLabelTextMarginLeft", dataToolTipLabelTextMarginRight: "dataToolTipLabelTextMarginRight", dataToolTipLabelTextMarginTop: "dataToolTipLabelTextMarginTop", dataToolTipLabelTextStyle: "dataToolTipLabelTextStyle", includedProperties: "includedProperties", excludedProperties: "excludedProperties", brushes: "brushes", outlines: "outlines", actualBrushes: "actualBrushes", actualOutlines: "actualOutlines", isHorizontalZoomEnabled: "isHorizontalZoomEnabled", isVerticalZoomEnabled: "isVerticalZoomEnabled", shouldDisplayMockData: "shouldDisplayMockData", shouldUseSkeletonStyleForMockData: "shouldUseSkeletonStyleForMockData", isSeriesHighlightingEnabled: "isSeriesHighlightingEnabled", windowRect: "windowRect", chartTitle: "chartTitle", subtitle: "subtitle", titleAlignment: "titleAlignment", subtitleAlignment: "subtitleAlignment", unknownValuePlotting: "unknownValuePlotting", resolution: "resolution", thickness: "thickness", outlineMode: "outlineMode", markerOutlineMode: "markerOutlineMode", markerFillMode: "markerFillMode", markerFillOpacity: "markerFillOpacity", markerThickness: "markerThickness", markerTypes: "markerTypes", markerAutomaticBehavior: "markerAutomaticBehavior", markerBrushes: "markerBrushes", markerOutlines: "markerOutlines", markerMaxCount: "markerMaxCount", areaFillOpacity: "areaFillOpacity", animateSeriesWhenAxisRangeChanges: "animateSeriesWhenAxisRangeChanges", trendLineBrushes: "trendLineBrushes", trendLineType: "trendLineType", trendLineThickness: "trendLineThickness", alignsGridLinesToPixels: "alignsGridLinesToPixels", plotAreaMarginLeft: "plotAreaMarginLeft", plotAreaMarginTop: "plotAreaMarginTop", plotAreaMarginRight: "plotAreaMarginRight", plotAreaMarginBottom: "plotAreaMarginBottom", computedPlotAreaMarginMode: "computedPlotAreaMarginMode", seriesPlotAreaMarginHorizontalMode: "seriesPlotAreaMarginHorizontalMode", seriesPlotAreaMarginVerticalMode: "seriesPlotAreaMarginVerticalMode", highlightingMode: "highlightingMode", highlightingBehavior: "highlightingBehavior", legendHighlightingMode: "legendHighlightingMode", legendItemBadgeShape: "legendItemBadgeShape", legendItemBadgeMode: "legendItemBadgeMode", trendLinePeriod: "trendLinePeriod", toolTipType: "toolTipType", crosshairsDisplayMode: "crosshairsDisplayMode", crosshairsSnapToData: "crosshairsSnapToData", crosshairsLineVerticalStroke: "crosshairsLineVerticalStroke", crosshairsLineThickness: "crosshairsLineThickness", crosshairsLineHorizontalStroke: "crosshairsLineHorizontalStroke", crosshairsAnnotationEnabled: "crosshairsAnnotationEnabled", crosshairsAnnotationXAxisBackground: "crosshairsAnnotationXAxisBackground", crosshairsAnnotationYAxisBackground: "crosshairsAnnotationYAxisBackground", crosshairsAnnotationXAxisTextColor: "crosshairsAnnotationXAxisTextColor", crosshairsAnnotationYAxisTextColor: "crosshairsAnnotationYAxisTextColor", crosshairsAnnotationXAxisPrecision: "crosshairsAnnotationXAxisPrecision", crosshairsAnnotationYAxisPrecision: "crosshairsAnnotationYAxisPrecision", shouldAvoidAxisAnnotationCollisions: "shouldAvoidAxisAnnotationCollisions", finalValueAnnotationsVisible: "finalValueAnnotationsVisible", finalValueAnnotationsBackground: "finalValueAnnotationsBackground", finalValueAnnotationsTextColor: "finalValueAnnotationsTextColor", finalValueAnnotationsPrecision: "finalValueAnnotationsPrecision", calloutsVisible: "calloutsVisible", calloutStyleUpdatingEventEnabled: "calloutStyleUpdatingEventEnabled", calloutsAllowedPositions: "calloutsAllowedPositions", calloutsXMemberPath: "calloutsXMemberPath", calloutsYMemberPath: "calloutsYMemberPath", calloutsLabelMemberPath: "calloutsLabelMemberPath", calloutsContentMemberPath: "calloutsContentMemberPath", horizontalViewScrollbarMode: "horizontalViewScrollbarMode", verticalViewScrollbarMode: "verticalViewScrollbarMode", horizontalViewScrollbarPosition: "horizontalViewScrollbarPosition", verticalViewScrollbarPosition: "verticalViewScrollbarPosition", horizontalViewScrollbarFill: "horizontalViewScrollbarFill", horizontalViewScrollbarOutline: "horizontalViewScrollbarOutline", horizontalViewScrollbarStrokeThickness: "horizontalViewScrollbarStrokeThickness", horizontalViewScrollbarMaxOpacity: "horizontalViewScrollbarMaxOpacity", horizontalViewScrollbarCornerRadius: "horizontalViewScrollbarCornerRadius", horizontalViewScrollbarHeight: "horizontalViewScrollbarHeight", horizontalViewScrollbarInset: "horizontalViewScrollbarInset", horizontalViewScrollbarTrackStartInset: "horizontalViewScrollbarTrackStartInset", horizontalViewScrollbarTrackEndInset: "horizontalViewScrollbarTrackEndInset", horizontalViewScrollbarShouldAddAutoTrackInsets: "horizontalViewScrollbarShouldAddAutoTrackInsets", verticalViewScrollbarFill: "verticalViewScrollbarFill", verticalViewScrollbarOutline: "verticalViewScrollbarOutline", verticalViewScrollbarStrokeThickness: "verticalViewScrollbarStrokeThickness", verticalViewScrollbarMaxOpacity: "verticalViewScrollbarMaxOpacity", verticalViewScrollbarCornerRadius: "verticalViewScrollbarCornerRadius", verticalViewScrollbarWidth: "verticalViewScrollbarWidth", verticalViewScrollbarInset: "verticalViewScrollbarInset", verticalViewScrollbarTrackStartInset: "verticalViewScrollbarTrackStartInset", verticalViewScrollbarTrackEndInset: "verticalViewScrollbarTrackEndInset", verticalViewScrollbarShouldAddAutoTrackInsets: "verticalViewScrollbarShouldAddAutoTrackInsets" }, outputs: { seriesAdded: "seriesAdded", seriesRemoved: "seriesRemoved", seriesPointerEnter: "seriesPointerEnter", seriesPointerLeave: "seriesPointerLeave", seriesPointerMove: "seriesPointerMove", seriesPointerDown: "seriesPointerDown", seriesPointerUp: "seriesPointerUp", calloutStyleUpdating: "calloutStyleUpdating", calloutRenderStyleUpdating: "calloutRenderStyleUpdating" }, ngImport: i0, template: "", isInline: true });
    return IgxDomainChartComponent;
}());
export { IgxDomainChartComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: IgxDomainChartComponent, decorators: [{
            type: Component,
            args: [{
                    template: "",
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { tooltipTemplate: [{
                type: Input
            }], tooltipTemplates: [{
                type: Input
            }], legend: [{
                type: Input
            }], calloutsDataSource: [{
                type: Input
            }], pixelScalingRatio: [{
                type: Input
            }], titleLeftMargin: [{
                type: Input
            }], titleRightMargin: [{
                type: Input
            }], titleTopMargin: [{
                type: Input
            }], titleBottomMargin: [{
                type: Input
            }], subtitleLeftMargin: [{
                type: Input
            }], subtitleTopMargin: [{
                type: Input
            }], subtitleRightMargin: [{
                type: Input
            }], subtitleBottomMargin: [{
                type: Input
            }], subtitleTextColor: [{
                type: Input
            }], titleTextColor: [{
                type: Input
            }], leftMargin: [{
                type: Input
            }], topMargin: [{
                type: Input
            }], rightMargin: [{
                type: Input
            }], bottomMargin: [{
                type: Input
            }], transitionDuration: [{
                type: Input
            }], transitionEasingFunction: [{
                type: Input
            }], subtitleTextStyle: [{
                type: Input
            }], titleTextStyle: [{
                type: Input
            }], dataToolTipGroupingMode: [{
                type: Input
            }], dataToolTipPositionOffsetX: [{
                type: Input
            }], dataToolTipPositionOffsetY: [{
                type: Input
            }], dataToolTipDefaultPositionOffsetX: [{
                type: Input
            }], dataToolTipDefaultPositionOffsetY: [{
                type: Input
            }], dataToolTipGroupedPositionModeX: [{
                type: Input
            }], dataToolTipGroupedPositionModeY: [{
                type: Input
            }], dataToolTipShouldUpdateWhenSeriesDataChanges: [{
                type: Input
            }], dataToolTipIncludedSeries: [{
                type: Input
            }], dataToolTipExcludedSeries: [{
                type: Input
            }], dataToolTipIncludedColumns: [{
                type: Input
            }], dataToolTipExcludedColumns: [{
                type: Input
            }], dataToolTipValueFormatAbbreviation: [{
                type: Input
            }], dataToolTipValueFormatMaxFractions: [{
                type: Input
            }], dataToolTipValueFormatMinFractions: [{
                type: Input
            }], dataToolTipValueFormatMode: [{
                type: Input
            }], dataToolTipValueFormatCulture: [{
                type: Input
            }], dataToolTipValueFormatUseGrouping: [{
                type: Input
            }], dataToolTipValueFormatString: [{
                type: Input
            }], dataToolTipValueFormatSpecifiers: [{
                type: Input
            }], dataToolTipValueRowMarginBottom: [{
                type: Input
            }], dataToolTipValueRowMarginLeft: [{
                type: Input
            }], dataToolTipValueRowMarginRight: [{
                type: Input
            }], dataToolTipValueRowMarginTop: [{
                type: Input
            }], dataToolTipValueRowVisible: [{
                type: Input
            }], dataToolTipValueTextWhenMissingData: [{
                type: Input
            }], dataToolTipValueTextUseSeriesColors: [{
                type: Input
            }], dataToolTipValueTextMarginBottom: [{
                type: Input
            }], dataToolTipValueTextMarginLeft: [{
                type: Input
            }], dataToolTipValueTextMarginRight: [{
                type: Input
            }], dataToolTipValueTextMarginTop: [{
                type: Input
            }], dataToolTipValueTextColor: [{
                type: Input
            }], dataToolTipValueTextStyle: [{
                type: Input
            }], dataToolTipHeaderFormatString: [{
                type: Input
            }], dataToolTipHeaderFormatSpecifiers: [{
                type: Input
            }], dataToolTipHeaderFormatCulture: [{
                type: Input
            }], dataToolTipHeaderFormatDate: [{
                type: Input
            }], dataToolTipHeaderFormatTime: [{
                type: Input
            }], dataToolTipHeaderText: [{
                type: Input
            }], dataToolTipHeaderTextColor: [{
                type: Input
            }], dataToolTipHeaderTextMarginBottom: [{
                type: Input
            }], dataToolTipHeaderTextMarginLeft: [{
                type: Input
            }], dataToolTipHeaderTextMarginRight: [{
                type: Input
            }], dataToolTipHeaderTextMarginTop: [{
                type: Input
            }], dataToolTipHeaderRowMarginBottom: [{
                type: Input
            }], dataToolTipHeaderRowMarginLeft: [{
                type: Input
            }], dataToolTipHeaderRowMarginRight: [{
                type: Input
            }], dataToolTipHeaderRowMarginTop: [{
                type: Input
            }], dataToolTipHeaderRowVisible: [{
                type: Input
            }], dataToolTipHeaderTextStyle: [{
                type: Input
            }], dataToolTipSummaryTitleTextColor: [{
                type: Input
            }], dataToolTipSummaryTitleTextStyle: [{
                type: Input
            }], dataToolTipSummaryType: [{
                type: Input
            }], dataToolTipSummaryTitleText: [{
                type: Input
            }], dataToolTipSummaryTitleTextMarginBottom: [{
                type: Input
            }], dataToolTipSummaryTitleTextMarginLeft: [{
                type: Input
            }], dataToolTipSummaryTitleTextMarginRight: [{
                type: Input
            }], dataToolTipSummaryTitleTextMarginTop: [{
                type: Input
            }], dataToolTipSummaryRowMarginBottom: [{
                type: Input
            }], dataToolTipSummaryRowMarginLeft: [{
                type: Input
            }], dataToolTipSummaryRowMarginRight: [{
                type: Input
            }], dataToolTipSummaryRowMarginTop: [{
                type: Input
            }], dataToolTipSummaryValueTextColor: [{
                type: Input
            }], dataToolTipSummaryValueTextStyle: [{
                type: Input
            }], dataToolTipSummaryLabelText: [{
                type: Input
            }], dataToolTipSummaryLabelTextColor: [{
                type: Input
            }], dataToolTipSummaryLabelTextStyle: [{
                type: Input
            }], dataToolTipSummaryUnitsText: [{
                type: Input
            }], dataToolTipSummaryUnitsTextColor: [{
                type: Input
            }], dataToolTipSummaryUnitsTextStyle: [{
                type: Input
            }], dataToolTipBadgeMarginBottom: [{
                type: Input
            }], dataToolTipBadgeMarginLeft: [{
                type: Input
            }], dataToolTipBadgeMarginRight: [{
                type: Input
            }], dataToolTipBadgeMarginTop: [{
                type: Input
            }], dataToolTipBadgeShape: [{
                type: Input
            }], dataToolTipUnitsDisplayMode: [{
                type: Input
            }], dataToolTipUnitsText: [{
                type: Input
            }], dataToolTipUnitsTextColor: [{
                type: Input
            }], dataToolTipUnitsTextMarginBottom: [{
                type: Input
            }], dataToolTipUnitsTextMarginLeft: [{
                type: Input
            }], dataToolTipUnitsTextMarginRight: [{
                type: Input
            }], dataToolTipUnitsTextMarginTop: [{
                type: Input
            }], dataToolTipUnitsTextStyle: [{
                type: Input
            }], dataToolTipTitleTextMarginBottom: [{
                type: Input
            }], dataToolTipTitleTextMarginLeft: [{
                type: Input
            }], dataToolTipTitleTextMarginRight: [{
                type: Input
            }], dataToolTipTitleTextMarginTop: [{
                type: Input
            }], dataToolTipTitleTextColor: [{
                type: Input
            }], dataToolTipTitleTextStyle: [{
                type: Input
            }], dataToolTipLabelDisplayMode: [{
                type: Input
            }], dataToolTipLabelTextColor: [{
                type: Input
            }], dataToolTipLabelTextMarginBottom: [{
                type: Input
            }], dataToolTipLabelTextMarginLeft: [{
                type: Input
            }], dataToolTipLabelTextMarginRight: [{
                type: Input
            }], dataToolTipLabelTextMarginTop: [{
                type: Input
            }], dataToolTipLabelTextStyle: [{
                type: Input
            }], includedProperties: [{
                type: Input
            }], excludedProperties: [{
                type: Input
            }], brushes: [{
                type: Input
            }], outlines: [{
                type: Input
            }], actualBrushes: [{
                type: Input
            }], actualOutlines: [{
                type: Input
            }], isHorizontalZoomEnabled: [{
                type: Input
            }], isVerticalZoomEnabled: [{
                type: Input
            }], shouldDisplayMockData: [{
                type: Input
            }], shouldUseSkeletonStyleForMockData: [{
                type: Input
            }], isSeriesHighlightingEnabled: [{
                type: Input
            }], windowRect: [{
                type: Input
            }], chartTitle: [{
                type: Input
            }], subtitle: [{
                type: Input
            }], titleAlignment: [{
                type: Input
            }], subtitleAlignment: [{
                type: Input
            }], unknownValuePlotting: [{
                type: Input
            }], resolution: [{
                type: Input
            }], thickness: [{
                type: Input
            }], outlineMode: [{
                type: Input
            }], markerOutlineMode: [{
                type: Input
            }], markerFillMode: [{
                type: Input
            }], markerFillOpacity: [{
                type: Input
            }], markerThickness: [{
                type: Input
            }], markerTypes: [{
                type: Input
            }], markerAutomaticBehavior: [{
                type: Input
            }], markerBrushes: [{
                type: Input
            }], markerOutlines: [{
                type: Input
            }], markerMaxCount: [{
                type: Input
            }], areaFillOpacity: [{
                type: Input
            }], animateSeriesWhenAxisRangeChanges: [{
                type: Input
            }], trendLineBrushes: [{
                type: Input
            }], trendLineType: [{
                type: Input
            }], trendLineThickness: [{
                type: Input
            }], alignsGridLinesToPixels: [{
                type: Input
            }], plotAreaMarginLeft: [{
                type: Input
            }], plotAreaMarginTop: [{
                type: Input
            }], plotAreaMarginRight: [{
                type: Input
            }], plotAreaMarginBottom: [{
                type: Input
            }], computedPlotAreaMarginMode: [{
                type: Input
            }], seriesPlotAreaMarginHorizontalMode: [{
                type: Input
            }], seriesPlotAreaMarginVerticalMode: [{
                type: Input
            }], highlightingMode: [{
                type: Input
            }], highlightingBehavior: [{
                type: Input
            }], legendHighlightingMode: [{
                type: Input
            }], legendItemBadgeShape: [{
                type: Input
            }], legendItemBadgeMode: [{
                type: Input
            }], trendLinePeriod: [{
                type: Input
            }], toolTipType: [{
                type: Input
            }], crosshairsDisplayMode: [{
                type: Input
            }], crosshairsSnapToData: [{
                type: Input
            }], crosshairsLineVerticalStroke: [{
                type: Input
            }], crosshairsLineThickness: [{
                type: Input
            }], crosshairsLineHorizontalStroke: [{
                type: Input
            }], crosshairsAnnotationEnabled: [{
                type: Input
            }], crosshairsAnnotationXAxisBackground: [{
                type: Input
            }], crosshairsAnnotationYAxisBackground: [{
                type: Input
            }], crosshairsAnnotationXAxisTextColor: [{
                type: Input
            }], crosshairsAnnotationYAxisTextColor: [{
                type: Input
            }], crosshairsAnnotationXAxisPrecision: [{
                type: Input
            }], crosshairsAnnotationYAxisPrecision: [{
                type: Input
            }], shouldAvoidAxisAnnotationCollisions: [{
                type: Input
            }], finalValueAnnotationsVisible: [{
                type: Input
            }], finalValueAnnotationsBackground: [{
                type: Input
            }], finalValueAnnotationsTextColor: [{
                type: Input
            }], finalValueAnnotationsPrecision: [{
                type: Input
            }], calloutsVisible: [{
                type: Input
            }], calloutStyleUpdatingEventEnabled: [{
                type: Input
            }], calloutsAllowedPositions: [{
                type: Input
            }], calloutsXMemberPath: [{
                type: Input
            }], calloutsYMemberPath: [{
                type: Input
            }], calloutsLabelMemberPath: [{
                type: Input
            }], calloutsContentMemberPath: [{
                type: Input
            }], horizontalViewScrollbarMode: [{
                type: Input
            }], verticalViewScrollbarMode: [{
                type: Input
            }], horizontalViewScrollbarPosition: [{
                type: Input
            }], verticalViewScrollbarPosition: [{
                type: Input
            }], horizontalViewScrollbarFill: [{
                type: Input
            }], horizontalViewScrollbarOutline: [{
                type: Input
            }], horizontalViewScrollbarStrokeThickness: [{
                type: Input
            }], horizontalViewScrollbarMaxOpacity: [{
                type: Input
            }], horizontalViewScrollbarCornerRadius: [{
                type: Input
            }], horizontalViewScrollbarHeight: [{
                type: Input
            }], horizontalViewScrollbarInset: [{
                type: Input
            }], horizontalViewScrollbarTrackStartInset: [{
                type: Input
            }], horizontalViewScrollbarTrackEndInset: [{
                type: Input
            }], horizontalViewScrollbarShouldAddAutoTrackInsets: [{
                type: Input
            }], verticalViewScrollbarFill: [{
                type: Input
            }], verticalViewScrollbarOutline: [{
                type: Input
            }], verticalViewScrollbarStrokeThickness: [{
                type: Input
            }], verticalViewScrollbarMaxOpacity: [{
                type: Input
            }], verticalViewScrollbarCornerRadius: [{
                type: Input
            }], verticalViewScrollbarWidth: [{
                type: Input
            }], verticalViewScrollbarInset: [{
                type: Input
            }], verticalViewScrollbarTrackStartInset: [{
                type: Input
            }], verticalViewScrollbarTrackEndInset: [{
                type: Input
            }], verticalViewScrollbarShouldAddAutoTrackInsets: [{
                type: Input
            }], seriesAdded: [{
                type: Output
            }], seriesRemoved: [{
                type: Output
            }], seriesPointerEnter: [{
                type: Output
            }], seriesPointerLeave: [{
                type: Output
            }], seriesPointerMove: [{
                type: Output
            }], seriesPointerDown: [{
                type: Output
            }], seriesPointerUp: [{
                type: Output
            }], calloutStyleUpdating: [{
                type: Output
            }], calloutRenderStyleUpdating: [{
                type: Output
            }] } });
