import { EventEmitter } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { CategoryTransitionInMode } from "./CategoryTransitionInMode";
import { IgxAssigningCategoryStyleEventArgs } from "./igx-assigning-category-style-event-args";
import { IgxAssigningCategoryMarkerStyleEventArgs } from "./igx-assigning-category-marker-style-event-args";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { CategorySeries } from "./CategorySeries";
import * as i0 from "@angular/core";
/**
 * Represents the base class for IgxDataChartComponent category series.
*
* `IgxCategorySeriesComponent` class represents the base class for IgxDataChartComponent category series.
*
* ```html
*     <igx-data-chart [dataSource]="data" >
*       <igx-category-x-axis
*         label="label"
*         #xAxis>
*       </igx-category-x-axis>
*       <igx-numeric-y-axis #yAxis>
*       </igx-numeric-y-axis>
*       <igx-column-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value"
*         isTransitionInEnabled="true">
*       </igx-column-series>
*     </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxColumnSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath="value";
* this.chart.series.add(series);
* ```
*/
export declare abstract class IgxCategorySeriesComponent extends IgxMarkerSeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): CategorySeries;
    constructor();
    get hasValueAxis(): boolean;
    static ngAcceptInputType_hasValueAxis: boolean | string;
    get isValueAxisInverted(): boolean;
    static ngAcceptInputType_isValueAxisInverted: boolean | string;
    /**
     * Gets whether or not this series is Category series
    */
    get isCategory(): boolean;
    static ngAcceptInputType_isCategory: boolean | string;
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
    */
    get isCustomCategoryStyleAllowed(): boolean;
    set isCustomCategoryStyleAllowed(v: boolean);
    static ngAcceptInputType_isCustomCategoryStyleAllowed: boolean | string;
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomCategoryMarkerStyleAllowed(): boolean;
    set isCustomCategoryMarkerStyleAllowed(v: boolean);
    static ngAcceptInputType_isCustomCategoryMarkerStyleAllowed: boolean | string;
    /**
     * Sets or Gets whether to increase marker fidelity for extreme data shapes that have lots of Y variation over short X intervals.
    *
    * Set `useHighMarkerFidelity` when your data has high variation along the y-axis within a short span of this x-axis.
    *
    * ```html
    * <igx-data-chart [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         markerType="circle"
    *         useHighMarkerFidelity="true">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxColumnSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.valueMemberPath= "value";
    * series.useHighMarkerFidelity= "true";
    * this.chart.series.add(series);
    * ```
    *
    * ```ts
    *       this.columnSeries2.useHighMarkerFidelity= "true";
    * ```
    */
    get useHighMarkerFidelity(): boolean;
    set useHighMarkerFidelity(v: boolean);
    static ngAcceptInputType_useHighMarkerFidelity: boolean | string;
    /**
     * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
     * Note: Transitions are not currently supported for stacked series.
    *
    * `transitionInMode` controls the direction of the transition-in animation.
    *
    * ```html
    *     <igx-data-chart
    *       [dataSource]="data" >
    *       <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *       </igx-category-x-axis>
    *       <igx-numeric-y-axis #yAxis>
    *       </igx-numeric-y-axis>
    *
    *       <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isTransitionInEnabled="true"
    *         transitionInMode="accordionfromRight">
    *       </igx-column-series>
    *     </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxColumnSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.valueMemberPath="value";
    * series.transitionInMode="accordionfromRight";
    * this.chart.series.add(series);
    * ```
    *
    * ```ts
    *
    * 	this.columnSeries2.transitionInMode= "accordionfromRight";
    * ```
    */
    get transitionInMode(): CategoryTransitionInMode;
    set transitionInMode(v: CategoryTransitionInMode);
    static ngAcceptInputType_transitionInMode: CategoryTransitionInMode | string;
    /**
     * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
     * Note: Transitions are not currently supported for stacked series.
    *
    * Set `isTransitionInEnabled` to true if you want your chart series to animate into position when the chart is loading into view.
    *
    * ```html
    *     <igx-data-chart [dataSource]="data" >
    *       <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *       </igx-category-x-axis>
    *       <igx-numeric-y-axis #yAxis>
    *       </igx-numeric-y-axis>
    *
    *       <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isTransitionInEnabled="true">
    *       </igx-column-series>
    *     </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxColumnSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.valueMemberPath="value";
    * series.isTransitionInEnabled="true";
    * this.chart.series.add(series);
    * ```
    */
    get isTransitionInEnabled(): boolean;
    set isTransitionInEnabled(v: boolean);
    static ngAcceptInputType_isTransitionInEnabled: boolean | string;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the index of the item based on world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    private _assigningCategoryStyle;
    /**
     * Event raised when Assigning Category Style
    */
    get assigningCategoryStyle(): EventEmitter<{
        sender: any;
        args: IgxAssigningCategoryStyleEventArgs;
    }>;
    private _assigningCategoryMarkerStyle;
    /**
     * Event raised when Assigning Category Marker Style
    */
    get assigningCategoryMarkerStyle(): EventEmitter<{
        sender: any;
        args: IgxAssigningCategoryMarkerStyleEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxCategorySeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxCategorySeriesComponent, "ng-component", never, { "isCustomCategoryStyleAllowed": "isCustomCategoryStyleAllowed"; "isCustomCategoryMarkerStyleAllowed": "isCustomCategoryMarkerStyleAllowed"; "useHighMarkerFidelity": "useHighMarkerFidelity"; "transitionInMode": "transitionInMode"; "isTransitionInEnabled": "isTransitionInEnabled"; }, { "assigningCategoryStyle": "assigningCategoryStyle"; "assigningCategoryMarkerStyle": "assigningCategoryMarkerStyle"; }, never, never>;
}
