import { EventEmitter, ViewContainerRef, Injector, ComponentFactoryResolver, AfterContentInit, Renderer2, NgZone } from '@angular/core';
import { XamDataLegend } from "./XamDataLegend";
import { DataAbbreviationMode } from "igniteui-angular-core";
import { DataLegendHeaderTimeMode } from "igniteui-angular-core";
import { DataLegendHeaderDateMode } from "igniteui-angular-core";
import { DataLegendUnitsMode } from "igniteui-angular-core";
import { DataLegendLabelMode } from "igniteui-angular-core";
import { DataLegendValueMode } from "igniteui-angular-core";
import { DataLegendSummaryType } from "igniteui-angular-core";
import { IgxDataLegendSummaryEventArgs } from './igx-data-legend-summary-event-args';
import { IgxDataLegendStylingRowEventArgs } from './igx-data-legend-styling-row-event-args';
import { IgxDataLegendStylingColumnEventArgs } from './igx-data-legend-styling-column-event-args';
import { LegendItemBadgeShape } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents data legend that displays information about each series including values and summaries.
 * THIS IS A COMMUNITY TECHNOLOGY PREVIEW, not for use in production.
*/
export declare class IgxDataLegendComponent implements AfterContentInit {
    private renderer;
    private _elRef;
    private ngZone;
    private injector;
    private componentFactoryResolver;
    container: Element;
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    _dynamicContent: ViewContainerRef;
    private _wrapper;
    private _root;
    constructor(renderer: Renderer2, _elRef: ViewContainerRef, ngZone: NgZone, injector: Injector, componentFactoryResolver: ComponentFactoryResolver);
    updateStyle(): void;
    ngOnDestroy(): void;
    private _implementation;
    ngAfterContentInit(): void;
    protected createImplementation(): XamDataLegend;
    get i(): XamDataLegend;
    private _dataLegend;
    protected static _staticStyling(container: any, component: any, parent?: any): void;
    /**
     * Gets or sets the target for the data legend.
    */
    get target(): any;
    set target(v: any);
    /**
 * Gets whether or not at least one badge is visible based on BadgesShape and setting of a row's IsVisble in StyleSeriesRow event
*/
    get actualBadgesVisible(): boolean;
    set actualBadgesVisible(v: boolean);
    static ngAcceptInputType_actualBadgesVisible: boolean | string;
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get actualPixelScalingRatio(): number;
    set actualPixelScalingRatio(v: number);
    static ngAcceptInputType_actualPixelScalingRatio: number | string;
    /**
     * Gets or sets indexes or names of series to include in displaying in the data legend, e.g. "0, 1"
    */
    get includedSeries(): string[];
    set includedSeries(v: string[]);
    static ngAcceptInputType_includedSeries: string[] | string;
    /**
     * Gets or sets indexes or names of series to exclude from displaying in the data legend, e.g. "0, 1"
     * The ExcludedSeries property takes precedences over values of IncludedSeries property
    */
    get excludedSeries(): string[];
    set excludedSeries(v: string[]);
    static ngAcceptInputType_excludedSeries: string[] | string;
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get includedColumns(): string[];
    set includedColumns(v: string[]);
    static ngAcceptInputType_includedColumns: string[] | string;
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get excludedColumns(): string[];
    set excludedColumns(v: string[]);
    static ngAcceptInputType_excludedColumns: string[] | string;
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get shouldUpdateWhenSeriesDataChanges(): boolean;
    set shouldUpdateWhenSeriesDataChanges(v: boolean);
    static ngAcceptInputType_shouldUpdateWhenSeriesDataChanges: boolean | string;
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatAbbreviation(): DataAbbreviationMode;
    set valueFormatAbbreviation(v: DataAbbreviationMode);
    static ngAcceptInputType_valueFormatAbbreviation: DataAbbreviationMode | string;
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMaxFractions(): number;
    set valueFormatMaxFractions(v: number);
    static ngAcceptInputType_valueFormatMaxFractions: number | string;
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMinFractions(): number;
    set valueFormatMinFractions(v: number);
    static ngAcceptInputType_valueFormatMinFractions: number | string;
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get valueFormatMode(): DataLegendValueMode;
    set valueFormatMode(v: DataLegendValueMode);
    static ngAcceptInputType_valueFormatMode: DataLegendValueMode | string;
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCulture(): string;
    set valueFormatCulture(v: string);
    /**
     * Gets or sets the currency code used for displaying currency symbol next to values, e.g. USD for $, EUR for €
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCurrencyCode(): string;
    set valueFormatCurrencyCode(v: string);
    /**
     * Gets or sets whether or not use groupping sperator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatUseGrouping(): boolean;
    set valueFormatUseGrouping(v: boolean);
    static ngAcceptInputType_valueFormatUseGrouping: boolean | string;
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get valueFormatString(): string;
    set valueFormatString(v: string);
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get valueFormatSpecifiers(): any[];
    set valueFormatSpecifiers(v: any[]);
    static ngAcceptInputType_valueFormatSpecifiers: any[] | string;
    get valueRowMarginBottom(): number;
    set valueRowMarginBottom(v: number);
    static ngAcceptInputType_valueRowMarginBottom: number | string;
    get valueRowMarginLeft(): number;
    set valueRowMarginLeft(v: number);
    static ngAcceptInputType_valueRowMarginLeft: number | string;
    get valueRowMarginRight(): number;
    set valueRowMarginRight(v: number);
    static ngAcceptInputType_valueRowMarginRight: number | string;
    get valueRowMarginTop(): number;
    set valueRowMarginTop(v: number);
    static ngAcceptInputType_valueRowMarginTop: number | string;
    ensureValueRowMargin(): void;
    /**
     * Gets or sets whether to show series rows.
    */
    get valueRowVisible(): boolean;
    set valueRowVisible(v: boolean);
    static ngAcceptInputType_valueRowVisible: boolean | string;
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get valueTextWhenMissingData(): string;
    set valueTextWhenMissingData(v: string);
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get valueTextUseSeriesColors(): boolean;
    set valueTextUseSeriesColors(v: boolean);
    static ngAcceptInputType_valueTextUseSeriesColors: boolean | string;
    get valueTextMarginBottom(): number;
    set valueTextMarginBottom(v: number);
    static ngAcceptInputType_valueTextMarginBottom: number | string;
    get valueTextMarginLeft(): number;
    set valueTextMarginLeft(v: number);
    static ngAcceptInputType_valueTextMarginLeft: number | string;
    get valueTextMarginRight(): number;
    set valueTextMarginRight(v: number);
    static ngAcceptInputType_valueTextMarginRight: number | string;
    get valueTextMarginTop(): number;
    set valueTextMarginTop(v: number);
    static ngAcceptInputType_valueTextMarginTop: number | string;
    ensureValueTextMargin(): void;
    /**
     * Gets or sets the units text color.
    */
    get valueTextColor(): string;
    set valueTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get valueTextStyle(): string;
    set valueTextStyle(v: string);
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get headerFormatString(): string;
    set headerFormatString(v: string);
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get headerFormatSpecifiers(): any[];
    set headerFormatSpecifiers(v: any[]);
    static ngAcceptInputType_headerFormatSpecifiers: any[] | string;
    /**
     * Gets or sets globalization culture applied to header only when it displays dates that are fetched from date/time axes
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatCulture(): string;
    set headerFormatCulture(v: string);
    /**
     * Gets or sets date format for the header only when it displays dates that are fetched from date/time axes
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatDate(): DataLegendHeaderDateMode;
    set headerFormatDate(v: DataLegendHeaderDateMode);
    static ngAcceptInputType_headerFormatDate: DataLegendHeaderDateMode | string;
    /**
     * Gets or sets time format for the header only when it displays dates that are fetched from date/time axes
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatTime(): DataLegendHeaderTimeMode;
    set headerFormatTime(v: DataLegendHeaderTimeMode);
    static ngAcceptInputType_headerFormatTime: DataLegendHeaderTimeMode | string;
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText(): string;
    set headerText(v: string);
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor(): string;
    set headerTextColor(v: string);
    get headerTextMarginBottom(): number;
    set headerTextMarginBottom(v: number);
    static ngAcceptInputType_headerTextMarginBottom: number | string;
    get headerTextMarginLeft(): number;
    set headerTextMarginLeft(v: number);
    static ngAcceptInputType_headerTextMarginLeft: number | string;
    get headerTextMarginRight(): number;
    set headerTextMarginRight(v: number);
    static ngAcceptInputType_headerTextMarginRight: number | string;
    get headerTextMarginTop(): number;
    set headerTextMarginTop(v: number);
    static ngAcceptInputType_headerTextMarginTop: number | string;
    ensureHeaderTextMargin(): void;
    get headerRowMarginBottom(): number;
    set headerRowMarginBottom(v: number);
    static ngAcceptInputType_headerRowMarginBottom: number | string;
    get headerRowMarginLeft(): number;
    set headerRowMarginLeft(v: number);
    static ngAcceptInputType_headerRowMarginLeft: number | string;
    get headerRowMarginRight(): number;
    set headerRowMarginRight(v: number);
    static ngAcceptInputType_headerRowMarginRight: number | string;
    get headerRowMarginTop(): number;
    set headerRowMarginTop(v: number);
    static ngAcceptInputType_headerRowMarginTop: number | string;
    ensureHeaderRowMargin(): void;
    /**
     * Gets or sets whether to show Header row.
    */
    get headerRowVisible(): boolean;
    set headerRowVisible(v: boolean);
    static ngAcceptInputType_headerRowVisible: boolean | string;
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextStyle(): string;
    set headerTextStyle(v: string);
    /**
     * Gets or sets the summary text color.
    */
    get summaryTitleTextColor(): string;
    set summaryTitleTextColor(v: string);
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTitleTextStyle(): string;
    set summaryTitleTextStyle(v: string);
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType(): DataLegendSummaryType;
    set summaryType(v: DataLegendSummaryType);
    static ngAcceptInputType_summaryType: DataLegendSummaryType | string;
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get summaryTitleText(): string;
    set summaryTitleText(v: string);
    get summaryTitleTextMarginBottom(): number;
    set summaryTitleTextMarginBottom(v: number);
    static ngAcceptInputType_summaryTitleTextMarginBottom: number | string;
    get summaryTitleTextMarginLeft(): number;
    set summaryTitleTextMarginLeft(v: number);
    static ngAcceptInputType_summaryTitleTextMarginLeft: number | string;
    get summaryTitleTextMarginRight(): number;
    set summaryTitleTextMarginRight(v: number);
    static ngAcceptInputType_summaryTitleTextMarginRight: number | string;
    get summaryTitleTextMarginTop(): number;
    set summaryTitleTextMarginTop(v: number);
    static ngAcceptInputType_summaryTitleTextMarginTop: number | string;
    ensureSummaryTitleTextMargin(): void;
    get summaryRowMarginBottom(): number;
    set summaryRowMarginBottom(v: number);
    static ngAcceptInputType_summaryRowMarginBottom: number | string;
    get summaryRowMarginLeft(): number;
    set summaryRowMarginLeft(v: number);
    static ngAcceptInputType_summaryRowMarginLeft: number | string;
    get summaryRowMarginRight(): number;
    set summaryRowMarginRight(v: number);
    static ngAcceptInputType_summaryRowMarginRight: number | string;
    get summaryRowMarginTop(): number;
    set summaryRowMarginTop(v: number);
    static ngAcceptInputType_summaryRowMarginTop: number | string;
    ensureSummaryRowMargin(): void;
    /**
     * Gets or sets the units text color.
    */
    get summaryValueTextColor(): string;
    set summaryValueTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryValueTextStyle(): string;
    set summaryValueTextStyle(v: string);
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryLabelText(): string;
    set summaryLabelText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get summaryLabelTextColor(): string;
    set summaryLabelTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryLabelTextStyle(): string;
    set summaryLabelTextStyle(v: string);
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryUnitsText(): string;
    set summaryUnitsText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get summaryUnitsTextColor(): string;
    set summaryUnitsTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryUnitsTextStyle(): string;
    set summaryUnitsTextStyle(v: string);
    get badgeMarginBottom(): number;
    set badgeMarginBottom(v: number);
    static ngAcceptInputType_badgeMarginBottom: number | string;
    get badgeMarginLeft(): number;
    set badgeMarginLeft(v: number);
    static ngAcceptInputType_badgeMarginLeft: number | string;
    get badgeMarginRight(): number;
    set badgeMarginRight(v: number);
    static ngAcceptInputType_badgeMarginRight: number | string;
    get badgeMarginTop(): number;
    set badgeMarginTop(v: number);
    static ngAcceptInputType_badgeMarginTop: number | string;
    ensureBadgeMargin(): void;
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get badgeShape(): LegendItemBadgeShape;
    set badgeShape(v: LegendItemBadgeShape);
    static ngAcceptInputType_badgeShape: LegendItemBadgeShape | string;
    /**
     * Gets or sets horizontal position (between 0.0 and 1.0) in viewport of the target component
    */
    get targetCursorPositionX(): number;
    set targetCursorPositionX(v: number);
    static ngAcceptInputType_targetCursorPositionX: number | string;
    /**
     * Gets or sets vertical position (between 0.0 and 1.0) in viewport of the target component
    */
    get targetCursorPositionY(): number;
    set targetCursorPositionY(v: number);
    static ngAcceptInputType_targetCursorPositionY: number | string;
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get unitsDisplayMode(): DataLegendUnitsMode;
    set unitsDisplayMode(v: DataLegendUnitsMode);
    static ngAcceptInputType_unitsDisplayMode: DataLegendUnitsMode | string;
    /**
     * Gets or sets the units text for the data legend.
    */
    get unitsText(): string;
    set unitsText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get unitsTextColor(): string;
    set unitsTextColor(v: string);
    get unitsTextMarginBottom(): number;
    set unitsTextMarginBottom(v: number);
    static ngAcceptInputType_unitsTextMarginBottom: number | string;
    get unitsTextMarginLeft(): number;
    set unitsTextMarginLeft(v: number);
    static ngAcceptInputType_unitsTextMarginLeft: number | string;
    get unitsTextMarginRight(): number;
    set unitsTextMarginRight(v: number);
    static ngAcceptInputType_unitsTextMarginRight: number | string;
    get unitsTextMarginTop(): number;
    set unitsTextMarginTop(v: number);
    static ngAcceptInputType_unitsTextMarginTop: number | string;
    ensureUnitsTextMargin(): void;
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextStyle(): string;
    set unitsTextStyle(v: string);
    get titleTextMarginBottom(): number;
    set titleTextMarginBottom(v: number);
    static ngAcceptInputType_titleTextMarginBottom: number | string;
    get titleTextMarginLeft(): number;
    set titleTextMarginLeft(v: number);
    static ngAcceptInputType_titleTextMarginLeft: number | string;
    get titleTextMarginRight(): number;
    set titleTextMarginRight(v: number);
    static ngAcceptInputType_titleTextMarginRight: number | string;
    get titleTextMarginTop(): number;
    set titleTextMarginTop(v: number);
    static ngAcceptInputType_titleTextMarginTop: number | string;
    ensureTitleTextMargin(): void;
    /**
     * Gets or sets the display text color.
    */
    get titleTextColor(): string;
    set titleTextColor(v: string);
    /**
     * Gets or Sets the style to use for the display text.
    */
    get titleTextStyle(): string;
    set titleTextStyle(v: string);
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get labelDisplayMode(): DataLegendLabelMode;
    set labelDisplayMode(v: DataLegendLabelMode);
    static ngAcceptInputType_labelDisplayMode: DataLegendLabelMode | string;
    /**
     * Gets or sets the units text color.
    */
    get labelTextColor(): string;
    set labelTextColor(v: string);
    get labelTextMarginBottom(): number;
    set labelTextMarginBottom(v: number);
    static ngAcceptInputType_labelTextMarginBottom: number | string;
    get labelTextMarginLeft(): number;
    set labelTextMarginLeft(v: number);
    static ngAcceptInputType_labelTextMarginLeft: number | string;
    get labelTextMarginRight(): number;
    set labelTextMarginRight(v: number);
    static ngAcceptInputType_labelTextMarginRight: number | string;
    get labelTextMarginTop(): number;
    set labelTextMarginTop(v: number);
    static ngAcceptInputType_labelTextMarginTop: number | string;
    ensureLabelTextMargin(): void;
    /**
     * Gets or Sets the style to use for the units text.
    */
    get labelTextStyle(): string;
    set labelTextStyle(v: string);
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control to appear blurry.
    */
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    static ngAcceptInputType_pixelScalingRatio: number | string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Returns the legend visuals expressed as a serialized string.

*/
    exportSerializedVisualData(): string;
    /**
     * Notifies the legend about changes to size
    
    */
    notifySizeChanged(): void;
    /**
     * Forces any pending refresh to the legend to be finished.
    
    */
    flush(): void;
    getAbbreviatedNumber(number: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): number;
    getAbbreviatedSymbol(number: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): string;
    getAbbreviatedString(number: number, mode: DataAbbreviationMode, minDigits: number, maxDigits: number): string;
    private _calculateColumnSummary;
    /**
     * Event raised when calculating summary value for each column in data legend
    */
    get calculateColumnSummary(): EventEmitter<{
        sender: any;
        args: IgxDataLegendSummaryEventArgs;
    }>;
    private _styleHeaderRow;
    /**
     * Event raised when styling the header row
    */
    get styleHeaderRow(): EventEmitter<{
        sender: any;
        args: IgxDataLegendStylingRowEventArgs;
    }>;
    private _styleSeriesRow;
    /**
     * Event raised when styling title and badge in series rows
    */
    get styleSeriesRow(): EventEmitter<{
        sender: any;
        args: IgxDataLegendStylingRowEventArgs;
    }>;
    private _styleSummaryRow;
    /**
     * Event raised when styling title in the summary row
    */
    get styleSummaryRow(): EventEmitter<{
        sender: any;
        args: IgxDataLegendStylingRowEventArgs;
    }>;
    private _styleSeriesColumn;
    /**
     * Event raised when styling the label, value, and unit columns in series rows
    */
    get styleSeriesColumn(): EventEmitter<{
        sender: any;
        args: IgxDataLegendStylingColumnEventArgs;
    }>;
    private _styleSummaryColumn;
    /**
     * Event raised when styling the label, value, and unit columns in summary row
    */
    get styleSummaryColumn(): EventEmitter<{
        sender: any;
        args: IgxDataLegendStylingColumnEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxDataLegendComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxDataLegendComponent, "igx-data-legend", never, { "height": "height"; "width": "width"; "target": "target"; "actualBadgesVisible": "actualBadgesVisible"; "actualPixelScalingRatio": "actualPixelScalingRatio"; "includedSeries": "includedSeries"; "excludedSeries": "excludedSeries"; "includedColumns": "includedColumns"; "excludedColumns": "excludedColumns"; "shouldUpdateWhenSeriesDataChanges": "shouldUpdateWhenSeriesDataChanges"; "valueFormatAbbreviation": "valueFormatAbbreviation"; "valueFormatMaxFractions": "valueFormatMaxFractions"; "valueFormatMinFractions": "valueFormatMinFractions"; "valueFormatMode": "valueFormatMode"; "valueFormatCulture": "valueFormatCulture"; "valueFormatCurrencyCode": "valueFormatCurrencyCode"; "valueFormatUseGrouping": "valueFormatUseGrouping"; "valueFormatString": "valueFormatString"; "valueFormatSpecifiers": "valueFormatSpecifiers"; "valueRowMarginBottom": "valueRowMarginBottom"; "valueRowMarginLeft": "valueRowMarginLeft"; "valueRowMarginRight": "valueRowMarginRight"; "valueRowMarginTop": "valueRowMarginTop"; "valueRowVisible": "valueRowVisible"; "valueTextWhenMissingData": "valueTextWhenMissingData"; "valueTextUseSeriesColors": "valueTextUseSeriesColors"; "valueTextMarginBottom": "valueTextMarginBottom"; "valueTextMarginLeft": "valueTextMarginLeft"; "valueTextMarginRight": "valueTextMarginRight"; "valueTextMarginTop": "valueTextMarginTop"; "valueTextColor": "valueTextColor"; "valueTextStyle": "valueTextStyle"; "headerFormatString": "headerFormatString"; "headerFormatSpecifiers": "headerFormatSpecifiers"; "headerFormatCulture": "headerFormatCulture"; "headerFormatDate": "headerFormatDate"; "headerFormatTime": "headerFormatTime"; "headerText": "headerText"; "headerTextColor": "headerTextColor"; "headerTextMarginBottom": "headerTextMarginBottom"; "headerTextMarginLeft": "headerTextMarginLeft"; "headerTextMarginRight": "headerTextMarginRight"; "headerTextMarginTop": "headerTextMarginTop"; "headerRowMarginBottom": "headerRowMarginBottom"; "headerRowMarginLeft": "headerRowMarginLeft"; "headerRowMarginRight": "headerRowMarginRight"; "headerRowMarginTop": "headerRowMarginTop"; "headerRowVisible": "headerRowVisible"; "headerTextStyle": "headerTextStyle"; "summaryTitleTextColor": "summaryTitleTextColor"; "summaryTitleTextStyle": "summaryTitleTextStyle"; "summaryType": "summaryType"; "summaryTitleText": "summaryTitleText"; "summaryTitleTextMarginBottom": "summaryTitleTextMarginBottom"; "summaryTitleTextMarginLeft": "summaryTitleTextMarginLeft"; "summaryTitleTextMarginRight": "summaryTitleTextMarginRight"; "summaryTitleTextMarginTop": "summaryTitleTextMarginTop"; "summaryRowMarginBottom": "summaryRowMarginBottom"; "summaryRowMarginLeft": "summaryRowMarginLeft"; "summaryRowMarginRight": "summaryRowMarginRight"; "summaryRowMarginTop": "summaryRowMarginTop"; "summaryValueTextColor": "summaryValueTextColor"; "summaryValueTextStyle": "summaryValueTextStyle"; "summaryLabelText": "summaryLabelText"; "summaryLabelTextColor": "summaryLabelTextColor"; "summaryLabelTextStyle": "summaryLabelTextStyle"; "summaryUnitsText": "summaryUnitsText"; "summaryUnitsTextColor": "summaryUnitsTextColor"; "summaryUnitsTextStyle": "summaryUnitsTextStyle"; "badgeMarginBottom": "badgeMarginBottom"; "badgeMarginLeft": "badgeMarginLeft"; "badgeMarginRight": "badgeMarginRight"; "badgeMarginTop": "badgeMarginTop"; "badgeShape": "badgeShape"; "targetCursorPositionX": "targetCursorPositionX"; "targetCursorPositionY": "targetCursorPositionY"; "unitsDisplayMode": "unitsDisplayMode"; "unitsText": "unitsText"; "unitsTextColor": "unitsTextColor"; "unitsTextMarginBottom": "unitsTextMarginBottom"; "unitsTextMarginLeft": "unitsTextMarginLeft"; "unitsTextMarginRight": "unitsTextMarginRight"; "unitsTextMarginTop": "unitsTextMarginTop"; "unitsTextStyle": "unitsTextStyle"; "titleTextMarginBottom": "titleTextMarginBottom"; "titleTextMarginLeft": "titleTextMarginLeft"; "titleTextMarginRight": "titleTextMarginRight"; "titleTextMarginTop": "titleTextMarginTop"; "titleTextColor": "titleTextColor"; "titleTextStyle": "titleTextStyle"; "labelDisplayMode": "labelDisplayMode"; "labelTextColor": "labelTextColor"; "labelTextMarginBottom": "labelTextMarginBottom"; "labelTextMarginLeft": "labelTextMarginLeft"; "labelTextMarginRight": "labelTextMarginRight"; "labelTextMarginTop": "labelTextMarginTop"; "labelTextStyle": "labelTextStyle"; "pixelScalingRatio": "pixelScalingRatio"; }, { "calculateColumnSummary": "calculateColumnSummary"; "styleHeaderRow": "styleHeaderRow"; "styleSeriesRow": "styleSeriesRow"; "styleSummaryRow": "styleSummaryRow"; "styleSeriesColumn": "styleSeriesColumn"; "styleSummaryColumn": "styleSummaryColumn"; }, never, never>;
}
