import { IgxHorizontalRangeCategorySeriesComponent } from "./igx-horizontal-range-category-series-component";
import { RangeAreaSeries } from "./RangeAreaSeries";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent range area series.
*
* The `IgxRangeAreaSeriesComponent` class represents the range area series of the IgxDataChartComponent.
*
* ```html
* <igx-data-chart
* [dataSource]="data">
* <igx-category-x-axis
* 	label="label"
* 	#xAxis>
* </igx-category-x-axis>
* <igx-numeric-y-axis
* 	#yAxis>
* </igx-numeric-y-axis>
*     <igx-range-area-series
*       [xAxis]="xAxis"
*       [yAxis]="yAxis"
*       highMemberPath="high"
*       lowMemberPath="low">
*   </igx-range-area-series>
*     </igx-data-chart>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxRangeAreaSeriesComponent = new IgxRangeAreaSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.highMemberPath = "High";
* series.lowMemberPath = "Low";
* this.chart.series.add(series);
* ```
*/
export declare class IgxRangeAreaSeriesComponent extends IgxHorizontalRangeCategorySeriesComponent {
    protected createImplementation(): RangeAreaSeries;
    /**
                                 * @hidden
                                 */
    get i(): RangeAreaSeries;
    constructor();
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Use the `isAreaOrLine` property to check if the current series shows an area or line shape.
    *
    * ```ts
    * var x= series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine(): boolean;
    static ngAcceptInputType_isAreaOrLine: boolean | string;
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea(): boolean;
    static ngAcceptInputType_isArea: boolean | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxRangeAreaSeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxRangeAreaSeriesComponent, "igx-range-area-series", never, {}, {}, never, never>;
}
